Class: Google::Apis::DriveV2::App

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

The apps resource provides a list of the apps that a user has installed, with information about each app's supported MIME types, file extensions, and other details. Some resource methods (such as apps.get) require an appId. Use the apps.list method to retrieve the ID for an installed application.

Defined Under Namespace

Classes: Icon

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ App

Returns a new instance of App.



599
600
601
# File 'lib/google/apis/drive_v2/classes.rb', line 599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizedBoolean Also known as: authorized?

Whether the app is authorized to access data on the user's Drive. Corresponds to the JSON property authorized

Returns:

  • (Boolean)


468
469
470
# File 'lib/google/apis/drive_v2/classes.rb', line 468

def authorized
  @authorized
end

#create_in_folder_templateString

The template url to create a new file with this app in a given folder. The template will contain folderId to be replaced by the folder to create the new file in. Corresponds to the JSON property createInFolderTemplate

Returns:

  • (String)


476
477
478
# File 'lib/google/apis/drive_v2/classes.rb', line 476

def create_in_folder_template
  @create_in_folder_template
end

#create_urlString

The url to create a new file with this app. Corresponds to the JSON property createUrl

Returns:

  • (String)


481
482
483
# File 'lib/google/apis/drive_v2/classes.rb', line 481

def create_url
  @create_url
end

#has_drive_wide_scopeBoolean Also known as: has_drive_wide_scope?

Whether the app has drive-wide scope. An app with drive-wide scope can access all files in the user's drive. Corresponds to the JSON property hasDriveWideScope

Returns:

  • (Boolean)


487
488
489
# File 'lib/google/apis/drive_v2/classes.rb', line 487

def has_drive_wide_scope
  @has_drive_wide_scope
end

#iconsArray<Google::Apis::DriveV2::App::Icon>

The various icons for the app. Corresponds to the JSON property icons



493
494
495
# File 'lib/google/apis/drive_v2/classes.rb', line 493

def icons
  @icons
end

#idString

The ID of the app. Corresponds to the JSON property id

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/drive_v2/classes.rb', line 498

def id
  @id
end

#installedBoolean Also known as: installed?

Whether the app is installed. Corresponds to the JSON property installed

Returns:

  • (Boolean)


503
504
505
# File 'lib/google/apis/drive_v2/classes.rb', line 503

def installed
  @installed
end

#kindString

This is always drive#app. Corresponds to the JSON property kind

Returns:

  • (String)


509
510
511
# File 'lib/google/apis/drive_v2/classes.rb', line 509

def kind
  @kind
end

#long_descriptionString

A long description of the app. Corresponds to the JSON property longDescription

Returns:

  • (String)


514
515
516
# File 'lib/google/apis/drive_v2/classes.rb', line 514

def long_description
  @long_description
end

#nameString

The name of the app. Corresponds to the JSON property name

Returns:

  • (String)


519
520
521
# File 'lib/google/apis/drive_v2/classes.rb', line 519

def name
  @name
end

#object_typeString

The type of object this app creates (e.g. Chart). If empty, the app name should be used instead. Corresponds to the JSON property objectType

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/drive_v2/classes.rb', line 525

def object_type
  @object_type
end

#open_url_templateString

The template url for opening files with this app. The template will contain ids and/or exportIds to be replaced by the actual file ids. See Open Files for the full documentation. Corresponds to the JSON property openUrlTemplate

Returns:

  • (String)


532
533
534
# File 'lib/google/apis/drive_v2/classes.rb', line 532

def open_url_template
  @open_url_template
end

#primary_file_extensionsArray<String>

The list of primary file extensions. Corresponds to the JSON property primaryFileExtensions

Returns:

  • (Array<String>)


537
538
539
# File 'lib/google/apis/drive_v2/classes.rb', line 537

def primary_file_extensions
  @primary_file_extensions
end

#primary_mime_typesArray<String>

The list of primary mime types. Corresponds to the JSON property primaryMimeTypes

Returns:

  • (Array<String>)


542
543
544
# File 'lib/google/apis/drive_v2/classes.rb', line 542

def primary_mime_types
  @primary_mime_types
end

#product_idString

The ID of the product listing for this app. Corresponds to the JSON property productId

Returns:

  • (String)


547
548
549
# File 'lib/google/apis/drive_v2/classes.rb', line 547

def product_id
  @product_id
end

#product_urlString

A link to the product listing for this app. Corresponds to the JSON property productUrl

Returns:

  • (String)


552
553
554
# File 'lib/google/apis/drive_v2/classes.rb', line 552

def product_url
  @product_url
end

#secondary_file_extensionsArray<String>

The list of secondary file extensions. Corresponds to the JSON property secondaryFileExtensions

Returns:

  • (Array<String>)


557
558
559
# File 'lib/google/apis/drive_v2/classes.rb', line 557

def secondary_file_extensions
  @secondary_file_extensions
end

#secondary_mime_typesArray<String>

The list of secondary mime types. Corresponds to the JSON property secondaryMimeTypes

Returns:

  • (Array<String>)


562
563
564
# File 'lib/google/apis/drive_v2/classes.rb', line 562

def secondary_mime_types
  @secondary_mime_types
end

#short_descriptionString

A short description of the app. Corresponds to the JSON property shortDescription

Returns:

  • (String)


567
568
569
# File 'lib/google/apis/drive_v2/classes.rb', line 567

def short_description
  @short_description
end

#supports_createBoolean Also known as: supports_create?

Whether this app supports creating new objects. Corresponds to the JSON property supportsCreate

Returns:

  • (Boolean)


572
573
574
# File 'lib/google/apis/drive_v2/classes.rb', line 572

def supports_create
  @supports_create
end

#supports_importBoolean Also known as: supports_import?

Whether this app supports importing from Docs Editors. Corresponds to the JSON property supportsImport

Returns:

  • (Boolean)


578
579
580
# File 'lib/google/apis/drive_v2/classes.rb', line 578

def supports_import
  @supports_import
end

#supports_multi_openBoolean Also known as: supports_multi_open?

Whether this app supports opening more than one file. Corresponds to the JSON property supportsMultiOpen

Returns:

  • (Boolean)


584
585
586
# File 'lib/google/apis/drive_v2/classes.rb', line 584

def supports_multi_open
  @supports_multi_open
end

#supports_offline_createBoolean Also known as: supports_offline_create?

Whether this app supports creating new files when offline. Corresponds to the JSON property supportsOfflineCreate

Returns:

  • (Boolean)


590
591
592
# File 'lib/google/apis/drive_v2/classes.rb', line 590

def supports_offline_create
  @supports_offline_create
end

#use_by_defaultBoolean Also known as: use_by_default?

Whether the app is selected as the default handler for the types it supports. Corresponds to the JSON property useByDefault

Returns:

  • (Boolean)


596
597
598
# File 'lib/google/apis/drive_v2/classes.rb', line 596

def use_by_default
  @use_by_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
# File 'lib/google/apis/drive_v2/classes.rb', line 604

def update!(**args)
  @authorized = args[:authorized] if args.key?(:authorized)
  @create_in_folder_template = args[:create_in_folder_template] if args.key?(:create_in_folder_template)
  @create_url = args[:create_url] if args.key?(:create_url)
  @has_drive_wide_scope = args[:has_drive_wide_scope] if args.key?(:has_drive_wide_scope)
  @icons = args[:icons] if args.key?(:icons)
  @id = args[:id] if args.key?(:id)
  @installed = args[:installed] if args.key?(:installed)
  @kind = args[:kind] if args.key?(:kind)
  @long_description = args[:long_description] if args.key?(:long_description)
  @name = args[:name] if args.key?(:name)
  @object_type = args[:object_type] if args.key?(:object_type)
  @open_url_template = args[:open_url_template] if args.key?(:open_url_template)
  @primary_file_extensions = args[:primary_file_extensions] if args.key?(:primary_file_extensions)
  @primary_mime_types = args[:primary_mime_types] if args.key?(:primary_mime_types)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_url = args[:product_url] if args.key?(:product_url)
  @secondary_file_extensions = args[:secondary_file_extensions] if args.key?(:secondary_file_extensions)
  @secondary_mime_types = args[:secondary_mime_types] if args.key?(:secondary_mime_types)
  @short_description = args[:short_description] if args.key?(:short_description)
  @supports_create = args[:supports_create] if args.key?(:supports_create)
  @supports_import = args[:supports_import] if args.key?(:supports_import)
  @supports_multi_open = args[:supports_multi_open] if args.key?(:supports_multi_open)
  @supports_offline_create = args[:supports_offline_create] if args.key?(:supports_offline_create)
  @use_by_default = args[:use_by_default] if args.key?(:use_by_default)
end