Class: Google::Apis::DriveV2::ChangeList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::ChangeList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
A list of changes for a user.
Instance Attribute Summary collapse
-
#etag ⇒ String
The ETag of the list.
-
#items ⇒ Array<Google::Apis::DriveV2::Change>
The list of changes.
-
#kind ⇒ String
This is always
drive#changeList. -
#largest_change_id ⇒ Fixnum
The current largest change ID.
-
#new_start_page_token ⇒ String
The starting page token for future changes.
-
#next_link ⇒ String
A link to the next page of changes.
-
#next_page_token ⇒ String
The page token for the next page of changes.
-
#self_link ⇒ String
A link back to this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChangeList
constructor
A new instance of ChangeList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChangeList
Returns a new instance of ChangeList.
855 856 857 |
# File 'lib/google/apis/drive_v2/classes.rb', line 855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
The ETag of the list.
Corresponds to the JSON property etag
813 814 815 |
# File 'lib/google/apis/drive_v2/classes.rb', line 813 def etag @etag end |
#items ⇒ Array<Google::Apis::DriveV2::Change>
The list of changes. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property items
819 820 821 |
# File 'lib/google/apis/drive_v2/classes.rb', line 819 def items @items end |
#kind ⇒ String
This is always drive#changeList.
Corresponds to the JSON property kind
824 825 826 |
# File 'lib/google/apis/drive_v2/classes.rb', line 824 def kind @kind end |
#largest_change_id ⇒ Fixnum
The current largest change ID.
Corresponds to the JSON property largestChangeId
829 830 831 |
# File 'lib/google/apis/drive_v2/classes.rb', line 829 def largest_change_id @largest_change_id end |
#new_start_page_token ⇒ String
The starting page token for future changes. This will be present only if the
end of the current changes list has been reached.
Corresponds to the JSON property newStartPageToken
835 836 837 |
# File 'lib/google/apis/drive_v2/classes.rb', line 835 def new_start_page_token @new_start_page_token end |
#next_link ⇒ String
A link to the next page of changes.
Corresponds to the JSON property nextLink
840 841 842 |
# File 'lib/google/apis/drive_v2/classes.rb', line 840 def next_link @next_link end |
#next_page_token ⇒ String
The page token for the next page of changes. This will be absent if the end of
the changes list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results.
Corresponds to the JSON property nextPageToken
848 849 850 |
# File 'lib/google/apis/drive_v2/classes.rb', line 848 def next_page_token @next_page_token end |
#self_link ⇒ String
A link back to this list.
Corresponds to the JSON property selfLink
853 854 855 |
# File 'lib/google/apis/drive_v2/classes.rb', line 853 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
860 861 862 863 864 865 866 867 868 869 |
# File 'lib/google/apis/drive_v2/classes.rb', line 860 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @largest_change_id = args[:largest_change_id] if args.key?(:largest_change_id) @new_start_page_token = args[:new_start_page_token] if args.key?(:new_start_page_token) @next_link = args[:next_link] if args.key?(:next_link) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |