Class: Google::Apis::DriveV2::ChildList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of children of a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChildList

Returns a new instance of ChildList.



989
990
991
# File 'lib/google/apis/drive_v2/classes.rb', line 989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The ETag of the list. Corresponds to the JSON property etag

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/drive_v2/classes.rb', line 958

def etag
  @etag
end

#itemsArray<Google::Apis::DriveV2::ChildReference>

The list of children. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items



964
965
966
# File 'lib/google/apis/drive_v2/classes.rb', line 964

def items
  @items
end

#kindString

This is always drive#childList. Corresponds to the JSON property kind

Returns:

  • (String)


969
970
971
# File 'lib/google/apis/drive_v2/classes.rb', line 969

def kind
  @kind
end

A link to the next page of children. Corresponds to the JSON property nextLink

Returns:

  • (String)


974
975
976
# File 'lib/google/apis/drive_v2/classes.rb', line 974

def next_link
  @next_link
end

#next_page_tokenString

The page token for the next page of children. This will be absent if the end of the children list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


982
983
984
# File 'lib/google/apis/drive_v2/classes.rb', line 982

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


987
988
989
# File 'lib/google/apis/drive_v2/classes.rb', line 987

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



994
995
996
997
998
999
1000
1001
# File 'lib/google/apis/drive_v2/classes.rb', line 994

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_link = args[:next_link] if args.key?(:next_link)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end