Class: Google::Apis::DriveV2::Comment::Context

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Context of a file which is being commented on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Context

Returns a new instance of Context.



1196
1197
1198
# File 'lib/google/apis/drive_v2/classes.rb', line 1196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The MIME type of the context snippet. Corresponds to the JSON property type

Returns:

  • (String)


1187
1188
1189
# File 'lib/google/apis/drive_v2/classes.rb', line 1187

def type
  @type
end

#valueString

Data representation of the segment of the file being commented on. In the case of a text file for example, this would be the actual text that the comment is about. Corresponds to the JSON property value

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/drive_v2/classes.rb', line 1194

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1201
1202
1203
1204
# File 'lib/google/apis/drive_v2/classes.rb', line 1201

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end