Class: Google::Apis::DriveV2::CommentList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of comments on a file in Google Drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommentList

Returns a new instance of CommentList.



1241
1242
1243
# File 'lib/google/apis/drive_v2/classes.rb', line 1241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DriveV2::Comment>

The list of comments. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items

Returns:



1216
1217
1218
# File 'lib/google/apis/drive_v2/classes.rb', line 1216

def items
  @items
end

#kindString

This is always drive#commentList. Corresponds to the JSON property kind

Returns:

  • (String)


1221
1222
1223
# File 'lib/google/apis/drive_v2/classes.rb', line 1221

def kind
  @kind
end

A link to the next page of comments. Corresponds to the JSON property nextLink

Returns:

  • (String)


1226
1227
1228
# File 'lib/google/apis/drive_v2/classes.rb', line 1226

def next_link
  @next_link
end

#next_page_tokenString

The page token for the next page of comments. This will be absent if the end of the comments list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/drive_v2/classes.rb', line 1234

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


1239
1240
1241
# File 'lib/google/apis/drive_v2/classes.rb', line 1239

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1246
1247
1248
1249
1250
1251
1252
# File 'lib/google/apis/drive_v2/classes.rb', line 1246

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_link = args[:next_link] if args.key?(:next_link)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end