Class: Google::Apis::DriveV2::CommentReply
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::CommentReply
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
A reply to a comment on a file in Google Drive.
Instance Attribute Summary collapse
-
#author ⇒ Google::Apis::DriveV2::User
Information about a Drive user.
-
#content ⇒ String
The plain text content used to create this reply.
-
#created_date ⇒ DateTime
The date when this reply was first created.
-
#deleted ⇒ Boolean
(also: #deleted?)
Whether this reply has been deleted.
-
#html_content ⇒ String
HTML formatted content for this reply.
-
#kind ⇒ String
This is always drive#commentReply.
-
#modified_date ⇒ DateTime
The date when this reply was last modified.
-
#reply_id ⇒ String
The ID of the reply.
-
#verb ⇒ String
The action this reply performed to the parent comment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommentReply
constructor
A new instance of CommentReply.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommentReply
Returns a new instance of CommentReply.
1311 1312 1313 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author ⇒ Google::Apis::DriveV2::User
Information about a Drive user.
Corresponds to the JSON property author
1262 1263 1264 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1262 def @author end |
#content ⇒ String
The plain text content used to create this reply. This is not HTML safe and
should only be used as a starting point to make edits to a reply's content.
This field is required on inserts if no verb is specified (resolve/reopen).
Corresponds to the JSON property content
1269 1270 1271 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1269 def content @content end |
#created_date ⇒ DateTime
The date when this reply was first created.
Corresponds to the JSON property createdDate
1274 1275 1276 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1274 def created_date @created_date end |
#deleted ⇒ Boolean Also known as: deleted?
Whether this reply has been deleted. If a reply has been deleted the content
will be cleared and this will only represent a reply that once existed.
Corresponds to the JSON property deleted
1280 1281 1282 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1280 def deleted @deleted end |
#html_content ⇒ String
HTML formatted content for this reply.
Corresponds to the JSON property htmlContent
1286 1287 1288 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1286 def html_content @html_content end |
#kind ⇒ String
This is always drive#commentReply.
Corresponds to the JSON property kind
1291 1292 1293 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1291 def kind @kind end |
#modified_date ⇒ DateTime
The date when this reply was last modified.
Corresponds to the JSON property modifiedDate
1296 1297 1298 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1296 def modified_date @modified_date end |
#reply_id ⇒ String
The ID of the reply.
Corresponds to the JSON property replyId
1301 1302 1303 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1301 def reply_id @reply_id end |
#verb ⇒ String
The action this reply performed to the parent comment. When creating a new
reply this is the action to be perform tSo the parent comment. Possible values
are: * resolve - To resolve a comment. * reopen - To reopen (un-resolve) a
comment.
Corresponds to the JSON property verb
1309 1310 1311 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1309 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/google/apis/drive_v2/classes.rb', line 1316 def update!(**args) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @created_date = args[:created_date] if args.key?(:created_date) @deleted = args[:deleted] if args.key?(:deleted) @html_content = args[:html_content] if args.key?(:html_content) @kind = args[:kind] if args.key?(:kind) @modified_date = args[:modified_date] if args.key?(:modified_date) @reply_id = args[:reply_id] if args.key?(:reply_id) @verb = args[:verb] if args.key?(:verb) end |