Class: Google::Apis::DriveV2::CommentReplyList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of replies to a comment on a file in Google Drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommentReplyList

Returns a new instance of CommentReplyList.



1362
1363
1364
# File 'lib/google/apis/drive_v2/classes.rb', line 1362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DriveV2::CommentReply>

The list of replies. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items



1337
1338
1339
# File 'lib/google/apis/drive_v2/classes.rb', line 1337

def items
  @items
end

#kindString

This is always drive#commentReplyList. Corresponds to the JSON property kind

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/drive_v2/classes.rb', line 1342

def kind
  @kind
end

A link to the next page of replies. Corresponds to the JSON property nextLink

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/drive_v2/classes.rb', line 1347

def next_link
  @next_link
end

#next_page_tokenString

The page token for the next page of replies. This will be absent if the end of the replies list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/drive_v2/classes.rb', line 1355

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/drive_v2/classes.rb', line 1360

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1367
1368
1369
1370
1371
1372
1373
# File 'lib/google/apis/drive_v2/classes.rb', line 1367

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_link = args[:next_link] if args.key?(:next_link)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end