Class: Google::Apis::DriveV2::DecryptionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Representation of the CSE DecryptionMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DecryptionMetadata

Returns a new instance of DecryptionMetadata.



1488
1489
1490
# File 'lib/google/apis/drive_v2/classes.rb', line 1488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aes256_gcm_chunk_sizeString

Chunk size used if content was encrypted with the AES 256 GCM Cipher. Possible values are: - default - small Corresponds to the JSON property aes256GcmChunkSize

Returns:

  • (String)


1451
1452
1453
# File 'lib/google/apis/drive_v2/classes.rb', line 1451

def aes256_gcm_chunk_size
  @aes256_gcm_chunk_size
end

#encryption_resource_key_hashString

The URL-safe Base64 encoded HMAC-SHA256 digest of the resource metadata with its DEK (Data Encryption Key); see https://developers.google.com/workspace/cse/ reference Corresponds to the JSON property encryptionResourceKeyHash

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/drive_v2/classes.rb', line 1458

def encryption_resource_key_hash
  @encryption_resource_key_hash
end

#jwtString

The signed JSON Web Token (JWT) which can be used to authorize the requesting user with the Key ACL Service (KACLS). The JWT asserts that the requesting user has at least read permissions on the file. Corresponds to the JSON property jwt

Returns:

  • (String)


1465
1466
1467
# File 'lib/google/apis/drive_v2/classes.rb', line 1465

def jwt
  @jwt
end

#kacls_idFixnum

The ID of the KACLS (Key ACL Service) used to encrypt the file. Corresponds to the JSON property kaclsId

Returns:

  • (Fixnum)


1470
1471
1472
# File 'lib/google/apis/drive_v2/classes.rb', line 1470

def kacls_id
  @kacls_id
end

#kacls_nameString

The name of the KACLS (Key ACL Service) used to encrypt the file. Corresponds to the JSON property kaclsName

Returns:

  • (String)


1475
1476
1477
# File 'lib/google/apis/drive_v2/classes.rb', line 1475

def kacls_name
  @kacls_name
end

#key_formatString

Key format for the unwrapped key. Must be tinkAesGcmKey. Corresponds to the JSON property keyFormat

Returns:

  • (String)


1480
1481
1482
# File 'lib/google/apis/drive_v2/classes.rb', line 1480

def key_format
  @key_format
end

#wrapped_keyString

The URL-safe Base64 encoded wrapped key used to encrypt the contents of the file. Corresponds to the JSON property wrappedKey

Returns:

  • (String)


1486
1487
1488
# File 'lib/google/apis/drive_v2/classes.rb', line 1486

def wrapped_key
  @wrapped_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1493
1494
1495
1496
1497
1498
1499
1500
1501
# File 'lib/google/apis/drive_v2/classes.rb', line 1493

def update!(**args)
  @aes256_gcm_chunk_size = args[:aes256_gcm_chunk_size] if args.key?(:aes256_gcm_chunk_size)
  @encryption_resource_key_hash = args[:encryption_resource_key_hash] if args.key?(:encryption_resource_key_hash)
  @jwt = args[:jwt] if args.key?(:jwt)
  @kacls_id = args[:kacls_id] if args.key?(:kacls_id)
  @kacls_name = args[:kacls_name] if args.key?(:kacls_name)
  @key_format = args[:key_format] if args.key?(:key_format)
  @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key)
end