Class: Google::Apis::DriveV2::Drive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Representation of a shared drive. Some resource methods (such as drives. update) require a driveId. Use the drives.list method to retrieve the ID for a shared drive.

Defined Under Namespace

Classes: BackgroundImageFile, Capabilities, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Drive

Returns a new instance of Drive.



1584
1585
1586
# File 'lib/google/apis/drive_v2/classes.rb', line 1584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_fileGoogle::Apis::DriveV2::Drive::BackgroundImageFile

An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on drive. drives.update requests that don't set themeId. When specified, all fields of the backgroundImageFile must be set. Corresponds to the JSON property backgroundImageFile



1516
1517
1518
# File 'lib/google/apis/drive_v2/classes.rb', line 1516

def background_image_file
  @background_image_file
end

Output only. A short-lived link to this shared drive's background image. Corresponds to the JSON property backgroundImageLink

Returns:

  • (String)


1521
1522
1523
# File 'lib/google/apis/drive_v2/classes.rb', line 1521

def background_image_link
  @background_image_link
end

#capabilitiesGoogle::Apis::DriveV2::Drive::Capabilities

Output only. Capabilities the current user has on this shared drive. Corresponds to the JSON property capabilities



1526
1527
1528
# File 'lib/google/apis/drive_v2/classes.rb', line 1526

def capabilities
  @capabilities
end

#color_rgbString

The color of this shared drive as an RGB hex string. It can only be set on a drive.drives.update request that does not set themeId. Corresponds to the JSON property colorRgb

Returns:

  • (String)


1532
1533
1534
# File 'lib/google/apis/drive_v2/classes.rb', line 1532

def color_rgb
  @color_rgb
end

#created_dateDateTime

The time at which the shared drive was created (RFC 3339 date-time). Corresponds to the JSON property createdDate

Returns:

  • (DateTime)


1537
1538
1539
# File 'lib/google/apis/drive_v2/classes.rb', line 1537

def created_date
  @created_date
end

#hiddenBoolean Also known as: hidden?

Whether the shared drive is hidden from default view. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


1542
1543
1544
# File 'lib/google/apis/drive_v2/classes.rb', line 1542

def hidden
  @hidden
end

#idString

Output only. The ID of this shared drive which is also the ID of the top level folder of this shared drive. Corresponds to the JSON property id

Returns:

  • (String)


1549
1550
1551
# File 'lib/google/apis/drive_v2/classes.rb', line 1549

def id
  @id
end

#kindString

Output only. This is always drive#drive Corresponds to the JSON property kind

Returns:

  • (String)


1554
1555
1556
# File 'lib/google/apis/drive_v2/classes.rb', line 1554

def kind
  @kind
end

#nameString

The name of this shared drive. Corresponds to the JSON property name

Returns:

  • (String)


1559
1560
1561
# File 'lib/google/apis/drive_v2/classes.rb', line 1559

def name
  @name
end

#org_unit_idString

Output only. The organizational unit of this shared drive. This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


1566
1567
1568
# File 'lib/google/apis/drive_v2/classes.rb', line 1566

def org_unit_id
  @org_unit_id
end

#restrictionsGoogle::Apis::DriveV2::Drive::Restrictions

A set of restrictions that apply to this shared drive or items inside this shared drive. Corresponds to the JSON property restrictions



1572
1573
1574
# File 'lib/google/apis/drive_v2/classes.rb', line 1572

def restrictions
  @restrictions
end

#theme_idString

The ID of the theme from which the background image and color will be set. The set of possible driveThemes can be retrieved from a drive.about.get response. When not specified on a drive.drives.insert request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set colorRgb or backgroundImageFile. Corresponds to the JSON property themeId

Returns:

  • (String)


1582
1583
1584
# File 'lib/google/apis/drive_v2/classes.rb', line 1582

def theme_id
  @theme_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
# File 'lib/google/apis/drive_v2/classes.rb', line 1589

def update!(**args)
  @background_image_file = args[:background_image_file] if args.key?(:background_image_file)
  @background_image_link = args[:background_image_link] if args.key?(:background_image_link)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @color_rgb = args[:color_rgb] if args.key?(:color_rgb)
  @created_date = args[:created_date] if args.key?(:created_date)
  @hidden = args[:hidden] if args.key?(:hidden)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @theme_id = args[:theme_id] if args.key?(:theme_id)
end