Class: Google::Apis::DriveV2::Drive::Capabilities

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Output only. Capabilities the current user has on this shared drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Capabilities

Returns a new instance of Capabilities.



1795
1796
1797
# File 'lib/google/apis/drive_v2/classes.rb', line 1795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_add_childrenBoolean Also known as: can_add_children?

Output only. Whether the current user can add children to folders in this shared drive. Corresponds to the JSON property canAddChildren

Returns:

  • (Boolean)


1662
1663
1664
# File 'lib/google/apis/drive_v2/classes.rb', line 1662

def can_add_children
  @can_add_children
end

#can_change_copy_requires_writer_permission_restrictionBoolean Also known as: can_change_copy_requires_writer_permission_restriction?

Output only. Whether the current user can change the copyRequiresWriterPermission restriction of this shared drive. Corresponds to the JSON property canChangeCopyRequiresWriterPermissionRestriction

Returns:

  • (Boolean)


1669
1670
1671
# File 'lib/google/apis/drive_v2/classes.rb', line 1669

def can_change_copy_requires_writer_permission_restriction
  @can_change_copy_requires_writer_permission_restriction
end

#can_change_domain_users_only_restrictionBoolean Also known as: can_change_domain_users_only_restriction?

Output only. Whether the current user can change the domainUsersOnly restriction of this shared drive. Corresponds to the JSON property canChangeDomainUsersOnlyRestriction

Returns:

  • (Boolean)


1676
1677
1678
# File 'lib/google/apis/drive_v2/classes.rb', line 1676

def can_change_domain_users_only_restriction
  @can_change_domain_users_only_restriction
end

#can_change_drive_backgroundBoolean Also known as: can_change_drive_background?

Output only. Whether the current user can change the background of this shared drive. Corresponds to the JSON property canChangeDriveBackground

Returns:

  • (Boolean)


1683
1684
1685
# File 'lib/google/apis/drive_v2/classes.rb', line 1683

def can_change_drive_background
  @can_change_drive_background
end

#can_change_drive_members_only_restrictionBoolean Also known as: can_change_drive_members_only_restriction?

Output only. Whether the current user can change the driveMembersOnly restriction of this shared drive. Corresponds to the JSON property canChangeDriveMembersOnlyRestriction

Returns:

  • (Boolean)


1690
1691
1692
# File 'lib/google/apis/drive_v2/classes.rb', line 1690

def can_change_drive_members_only_restriction
  @can_change_drive_members_only_restriction
end

#can_change_sharing_folders_requires_organizer_permission_restrictionBoolean Also known as: can_change_sharing_folders_requires_organizer_permission_restriction?

Output only. Whether the current user can change the sharingFoldersRequiresOrganizerPermission restriction of this shared drive. Corresponds to the JSON property canChangeSharingFoldersRequiresOrganizerPermissionRestriction

Returns:

  • (Boolean)


1697
1698
1699
# File 'lib/google/apis/drive_v2/classes.rb', line 1697

def can_change_sharing_folders_requires_organizer_permission_restriction
  @can_change_sharing_folders_requires_organizer_permission_restriction
end

#can_commentBoolean Also known as: can_comment?

Output only. Whether the current user can comment on files in this shared drive. Corresponds to the JSON property canComment

Returns:

  • (Boolean)


1704
1705
1706
# File 'lib/google/apis/drive_v2/classes.rb', line 1704

def can_comment
  @can_comment
end

#can_copyBoolean Also known as: can_copy?

Output only. Whether the current user can copy files in this shared drive. Corresponds to the JSON property canCopy

Returns:

  • (Boolean)


1710
1711
1712
# File 'lib/google/apis/drive_v2/classes.rb', line 1710

def can_copy
  @can_copy
end

#can_delete_childrenBoolean Also known as: can_delete_children?

Output only. Whether the current user can delete children from folders in this shared drive. Corresponds to the JSON property canDeleteChildren

Returns:

  • (Boolean)


1717
1718
1719
# File 'lib/google/apis/drive_v2/classes.rb', line 1717

def can_delete_children
  @can_delete_children
end

#can_delete_driveBoolean Also known as: can_delete_drive?

Output only. Whether the current user can delete this shared drive. Attempting to delete the shared drive may still fail if there are untrashed items inside the shared drive. Corresponds to the JSON property canDeleteDrive

Returns:

  • (Boolean)


1725
1726
1727
# File 'lib/google/apis/drive_v2/classes.rb', line 1725

def can_delete_drive
  @can_delete_drive
end

#can_downloadBoolean Also known as: can_download?

Output only. Whether the current user can download files in this shared drive. Corresponds to the JSON property canDownload

Returns:

  • (Boolean)


1731
1732
1733
# File 'lib/google/apis/drive_v2/classes.rb', line 1731

def can_download
  @can_download
end

#can_editBoolean Also known as: can_edit?

Output only. Whether the current user can edit files in this shared drive Corresponds to the JSON property canEdit

Returns:

  • (Boolean)


1737
1738
1739
# File 'lib/google/apis/drive_v2/classes.rb', line 1737

def can_edit
  @can_edit
end

#can_list_childrenBoolean Also known as: can_list_children?

Output only. Whether the current user can list the children of folders in this shared drive. Corresponds to the JSON property canListChildren

Returns:

  • (Boolean)


1744
1745
1746
# File 'lib/google/apis/drive_v2/classes.rb', line 1744

def can_list_children
  @can_list_children
end

#can_manage_membersBoolean Also known as: can_manage_members?

Output only. Whether the current user can add members to this shared drive or remove them or change their role. Corresponds to the JSON property canManageMembers

Returns:

  • (Boolean)


1751
1752
1753
# File 'lib/google/apis/drive_v2/classes.rb', line 1751

def can_manage_members
  @can_manage_members
end

#can_read_revisionsBoolean Also known as: can_read_revisions?

Output only. Whether the current user can read the revisions resource of files in this shared drive. Corresponds to the JSON property canReadRevisions

Returns:

  • (Boolean)


1758
1759
1760
# File 'lib/google/apis/drive_v2/classes.rb', line 1758

def can_read_revisions
  @can_read_revisions
end

#can_renameBoolean Also known as: can_rename?

Output only. Whether the current user can rename files or folders in this shared drive. Corresponds to the JSON property canRename

Returns:

  • (Boolean)


1765
1766
1767
# File 'lib/google/apis/drive_v2/classes.rb', line 1765

def can_rename
  @can_rename
end

#can_rename_driveBoolean Also known as: can_rename_drive?

Output only. Whether the current user can rename this shared drive. Corresponds to the JSON property canRenameDrive

Returns:

  • (Boolean)


1771
1772
1773
# File 'lib/google/apis/drive_v2/classes.rb', line 1771

def can_rename_drive
  @can_rename_drive
end

#can_reset_drive_restrictionsBoolean Also known as: can_reset_drive_restrictions?

Output only. Whether the current user can reset the shared drive restrictions to defaults. Corresponds to the JSON property canResetDriveRestrictions

Returns:

  • (Boolean)


1778
1779
1780
# File 'lib/google/apis/drive_v2/classes.rb', line 1778

def can_reset_drive_restrictions
  @can_reset_drive_restrictions
end

#can_shareBoolean Also known as: can_share?

Output only. Whether the current user can share files or folders in this shared drive. Corresponds to the JSON property canShare

Returns:

  • (Boolean)


1785
1786
1787
# File 'lib/google/apis/drive_v2/classes.rb', line 1785

def can_share
  @can_share
end

#can_trash_childrenBoolean Also known as: can_trash_children?

Output only. Whether the current user can trash children from folders in this shared drive. Corresponds to the JSON property canTrashChildren

Returns:

  • (Boolean)


1792
1793
1794
# File 'lib/google/apis/drive_v2/classes.rb', line 1792

def can_trash_children
  @can_trash_children
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/google/apis/drive_v2/classes.rb', line 1800

def update!(**args)
  @can_add_children = args[:can_add_children] if args.key?(:can_add_children)
  @can_change_copy_requires_writer_permission_restriction = args[:can_change_copy_requires_writer_permission_restriction] if args.key?(:can_change_copy_requires_writer_permission_restriction)
  @can_change_domain_users_only_restriction = args[:can_change_domain_users_only_restriction] if args.key?(:can_change_domain_users_only_restriction)
  @can_change_drive_background = args[:can_change_drive_background] if args.key?(:can_change_drive_background)
  @can_change_drive_members_only_restriction = args[:can_change_drive_members_only_restriction] if args.key?(:can_change_drive_members_only_restriction)
  @can_change_sharing_folders_requires_organizer_permission_restriction = args[:can_change_sharing_folders_requires_organizer_permission_restriction] if args.key?(:can_change_sharing_folders_requires_organizer_permission_restriction)
  @can_comment = args[:can_comment] if args.key?(:can_comment)
  @can_copy = args[:can_copy] if args.key?(:can_copy)
  @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children)
  @can_delete_drive = args[:can_delete_drive] if args.key?(:can_delete_drive)
  @can_download = args[:can_download] if args.key?(:can_download)
  @can_edit = args[:can_edit] if args.key?(:can_edit)
  @can_list_children = args[:can_list_children] if args.key?(:can_list_children)
  @can_manage_members = args[:can_manage_members] if args.key?(:can_manage_members)
  @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions)
  @can_rename = args[:can_rename] if args.key?(:can_rename)
  @can_rename_drive = args[:can_rename_drive] if args.key?(:can_rename_drive)
  @can_reset_drive_restrictions = args[:can_reset_drive_restrictions] if args.key?(:can_reset_drive_restrictions)
  @can_share = args[:can_share] if args.key?(:can_share)
  @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children)
end