Class: Google::Apis::DriveV2::Drive::Restrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A set of restrictions that apply to this shared drive or items inside this shared drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Restrictions

Returns a new instance of Restrictions.



1867
1868
1869
# File 'lib/google/apis/drive_v2/classes.rb', line 1867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_managed_restrictionsBoolean Also known as: admin_managed_restrictions?

Whether administrative privileges on this shared drive are required to modify restrictions. Corresponds to the JSON property adminManagedRestrictions

Returns:

  • (Boolean)


1833
1834
1835
# File 'lib/google/apis/drive_v2/classes.rb', line 1833

def admin_managed_restrictions
  @admin_managed_restrictions
end

#copy_requires_writer_permissionBoolean Also known as: copy_requires_writer_permission?

Whether the options to copy, print, or download files inside this shared drive, should be disabled for readers and commenters. When this restriction is set to true, it will override the similarly named field to true for any file inside this shared drive. Corresponds to the JSON property copyRequiresWriterPermission

Returns:

  • (Boolean)


1842
1843
1844
# File 'lib/google/apis/drive_v2/classes.rb', line 1842

def copy_requires_writer_permission
  @copy_requires_writer_permission
end

#domain_users_onlyBoolean Also known as: domain_users_only?

Whether access to this shared drive and items inside this shared drive is restricted to users of the domain to which this shared drive belongs. This restriction may be overridden by other sharing policies controlled outside of this shared drive. Corresponds to the JSON property domainUsersOnly

Returns:

  • (Boolean)


1851
1852
1853
# File 'lib/google/apis/drive_v2/classes.rb', line 1851

def domain_users_only
  @domain_users_only
end

#drive_members_onlyBoolean Also known as: drive_members_only?

Whether access to items inside this shared drive is restricted to its members. Corresponds to the JSON property driveMembersOnly

Returns:

  • (Boolean)


1857
1858
1859
# File 'lib/google/apis/drive_v2/classes.rb', line 1857

def drive_members_only
  @drive_members_only
end

#sharing_folders_requires_organizer_permissionBoolean Also known as: sharing_folders_requires_organizer_permission?

If true, only users with the organizer role can share folders. If false, users with either the organizer role or the file organizer role can share folders. Corresponds to the JSON property sharingFoldersRequiresOrganizerPermission

Returns:

  • (Boolean)


1864
1865
1866
# File 'lib/google/apis/drive_v2/classes.rb', line 1864

def sharing_folders_requires_organizer_permission
  @sharing_folders_requires_organizer_permission
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1872
1873
1874
1875
1876
1877
1878
# File 'lib/google/apis/drive_v2/classes.rb', line 1872

def update!(**args)
  @admin_managed_restrictions = args[:admin_managed_restrictions] if args.key?(:admin_managed_restrictions)
  @copy_requires_writer_permission = args[:copy_requires_writer_permission] if args.key?(:copy_requires_writer_permission)
  @domain_users_only = args[:domain_users_only] if args.key?(:domain_users_only)
  @drive_members_only = args[:drive_members_only] if args.key?(:drive_members_only)
  @sharing_folders_requires_organizer_permission = args[:sharing_folders_requires_organizer_permission] if args.key?(:sharing_folders_requires_organizer_permission)
end