Class: Google::Apis::DriveV2::DriveList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of shared drives.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DriveList

Returns a new instance of DriveList.



1905
1906
1907
# File 'lib/google/apis/drive_v2/classes.rb', line 1905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DriveV2::Drive>

The list of shared drives. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items

Returns:



1890
1891
1892
# File 'lib/google/apis/drive_v2/classes.rb', line 1890

def items
  @items
end

#kindString

This is always drive#driveList Corresponds to the JSON property kind

Returns:

  • (String)


1895
1896
1897
# File 'lib/google/apis/drive_v2/classes.rb', line 1895

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of shared drives. This will be absent if the end of the list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1903
1904
1905
# File 'lib/google/apis/drive_v2/classes.rb', line 1903

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1910
1911
1912
1913
1914
# File 'lib/google/apis/drive_v2/classes.rb', line 1910

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end