Class: Google::Apis::DriveV2::File::Capabilities
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::File::Capabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
Output only. Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take.
Instance Attribute Summary collapse
-
#can_accept_ownership ⇒ Boolean
(also: #can_accept_ownership?)
Output only.
-
#can_add_children ⇒ Boolean
(also: #can_add_children?)
Output only.
-
#can_add_folder_from_another_drive ⇒ Boolean
(also: #can_add_folder_from_another_drive?)
Output only.
-
#can_add_my_drive_parent ⇒ Boolean
(also: #can_add_my_drive_parent?)
Output only.
-
#can_change_copy_requires_writer_permission ⇒ Boolean
(also: #can_change_copy_requires_writer_permission?)
Output only.
-
#can_change_restricted_download ⇒ Boolean
(also: #can_change_restricted_download?)
Output only.
-
#can_change_security_update_enabled ⇒ Boolean
(also: #can_change_security_update_enabled?)
Output only.
-
#can_comment ⇒ Boolean
(also: #can_comment?)
Output only.
-
#can_copy ⇒ Boolean
(also: #can_copy?)
Output only.
-
#can_delete ⇒ Boolean
(also: #can_delete?)
Output only.
-
#can_delete_children ⇒ Boolean
(also: #can_delete_children?)
Output only.
-
#can_disable_inherited_permissions ⇒ Boolean
(also: #can_disable_inherited_permissions?)
Output only.
-
#can_download ⇒ Boolean
(also: #can_download?)
Output only.
-
#can_edit ⇒ Boolean
(also: #can_edit?)
Output only.
-
#can_enable_inherited_permissions ⇒ Boolean
(also: #can_enable_inherited_permissions?)
Output only.
-
#can_list_children ⇒ Boolean
(also: #can_list_children?)
Output only.
-
#can_modify_content ⇒ Boolean
(also: #can_modify_content?)
Output only.
-
#can_modify_content_restriction ⇒ Boolean
(also: #can_modify_content_restriction?)
Deprecated: Output only.
-
#can_modify_editor_content_restriction ⇒ Boolean
(also: #can_modify_editor_content_restriction?)
Output only.
-
#can_modify_labels ⇒ Boolean
(also: #can_modify_labels?)
Output only.
-
#can_modify_owner_content_restriction ⇒ Boolean
(also: #can_modify_owner_content_restriction?)
Output only.
-
#can_move_children_out_of_drive ⇒ Boolean
(also: #can_move_children_out_of_drive?)
Output only.
-
#can_move_children_out_of_team_drive ⇒ Boolean
(also: #can_move_children_out_of_team_drive?)
Output only.
-
#can_move_children_within_drive ⇒ Boolean
(also: #can_move_children_within_drive?)
Output only.
-
#can_move_children_within_team_drive ⇒ Boolean
(also: #can_move_children_within_team_drive?)
Output only.
-
#can_move_item_into_team_drive ⇒ Boolean
(also: #can_move_item_into_team_drive?)
Output only.
-
#can_move_item_out_of_drive ⇒ Boolean
(also: #can_move_item_out_of_drive?)
Output only.
-
#can_move_item_out_of_team_drive ⇒ Boolean
(also: #can_move_item_out_of_team_drive?)
Output only.
-
#can_move_item_within_drive ⇒ Boolean
(also: #can_move_item_within_drive?)
Output only.
-
#can_move_item_within_team_drive ⇒ Boolean
(also: #can_move_item_within_team_drive?)
Output only.
-
#can_move_team_drive_item ⇒ Boolean
(also: #can_move_team_drive_item?)
Output only.
-
#can_read_drive ⇒ Boolean
(also: #can_read_drive?)
Output only.
-
#can_read_labels ⇒ Boolean
(also: #can_read_labels?)
Output only.
-
#can_read_revisions ⇒ Boolean
(also: #can_read_revisions?)
Output only.
-
#can_read_team_drive ⇒ Boolean
(also: #can_read_team_drive?)
Output only.
-
#can_remove_children ⇒ Boolean
(also: #can_remove_children?)
Output only.
-
#can_remove_content_restriction ⇒ Boolean
(also: #can_remove_content_restriction?)
Output only.
-
#can_remove_my_drive_parent ⇒ Boolean
(also: #can_remove_my_drive_parent?)
Output only.
-
#can_rename ⇒ Boolean
(also: #can_rename?)
Output only.
-
#can_share ⇒ Boolean
(also: #can_share?)
Output only.
-
#can_trash ⇒ Boolean
(also: #can_trash?)
Output only.
-
#can_trash_children ⇒ Boolean
(also: #can_trash_children?)
Output only.
-
#can_untrash ⇒ Boolean
(also: #can_untrash?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Capabilities
constructor
A new instance of Capabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Capabilities
Returns a new instance of Capabilities.
2786 2787 2788 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_accept_ownership ⇒ Boolean Also known as: can_accept_ownership?
Output only. Whether the current user is the pending owner of the file. Not
populated for shared drive files.
Corresponds to the JSON property canAcceptOwnership
2493 2494 2495 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2493 def can_accept_ownership @can_accept_ownership end |
#can_add_children ⇒ Boolean Also known as: can_add_children?
Output only. Whether the current user can add children to this folder. This is
always false when the item is not a folder.
Corresponds to the JSON property canAddChildren
2500 2501 2502 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2500 def can_add_children @can_add_children end |
#can_add_folder_from_another_drive ⇒ Boolean Also known as: can_add_folder_from_another_drive?
Output only. Whether the current user can add a folder from another drive (
different shared drive or My Drive) to this folder. This is false when the
item is not a folder. Only populated for items in shared drives.
Corresponds to the JSON property canAddFolderFromAnotherDrive
2508 2509 2510 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2508 def can_add_folder_from_another_drive @can_add_folder_from_another_drive end |
#can_add_my_drive_parent ⇒ Boolean Also known as: can_add_my_drive_parent?
Output only. Whether the current user can add a parent for the item without
removing an existing parent in the same request. Not populated for shared
drive files.
Corresponds to the JSON property canAddMyDriveParent
2516 2517 2518 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2516 def can_add_my_drive_parent @can_add_my_drive_parent end |
#can_change_copy_requires_writer_permission ⇒ Boolean Also known as: can_change_copy_requires_writer_permission?
Output only. Whether the current user can change the
copyRequiresWriterPermission restriction of this file.
Corresponds to the JSON property canChangeCopyRequiresWriterPermission
2523 2524 2525 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2523 def @can_change_copy_requires_writer_permission end |
#can_change_restricted_download ⇒ Boolean Also known as: can_change_restricted_download?
Output only. Deprecated.
Corresponds to the JSON property canChangeRestrictedDownload
2529 2530 2531 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2529 def can_change_restricted_download @can_change_restricted_download end |
#can_change_security_update_enabled ⇒ Boolean Also known as: can_change_security_update_enabled?
Output only. Whether the current user can change the securityUpdateEnabled
field on link share metadata.
Corresponds to the JSON property canChangeSecurityUpdateEnabled
2536 2537 2538 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2536 def can_change_security_update_enabled @can_change_security_update_enabled end |
#can_comment ⇒ Boolean Also known as: can_comment?
Output only. Whether the current user can comment on this file.
Corresponds to the JSON property canComment
2542 2543 2544 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2542 def can_comment @can_comment end |
#can_copy ⇒ Boolean Also known as: can_copy?
Output only. Whether the current user can copy this file. For an item in a
shared drive, whether the current user can copy non-folder descendants of this
item, or this item itself if it is not a folder.
Corresponds to the JSON property canCopy
2550 2551 2552 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2550 def can_copy @can_copy end |
#can_delete ⇒ Boolean Also known as: can_delete?
Output only. Whether the current user can delete this file.
Corresponds to the JSON property canDelete
2556 2557 2558 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2556 def can_delete @can_delete end |
#can_delete_children ⇒ Boolean Also known as: can_delete_children?
Output only. Whether the current user can delete children of this folder. This
is false when the item is not a folder. Only populated for items in shared
drives.
Corresponds to the JSON property canDeleteChildren
2564 2565 2566 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2564 def can_delete_children @can_delete_children end |
#can_disable_inherited_permissions ⇒ Boolean Also known as: can_disable_inherited_permissions?
Output only. Whether a user can disable inherited permissions.
Corresponds to the JSON property canDisableInheritedPermissions
2570 2571 2572 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2570 def @can_disable_inherited_permissions end |
#can_download ⇒ Boolean Also known as: can_download?
Output only. Whether the current user can download this file.
Corresponds to the JSON property canDownload
2576 2577 2578 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2576 def can_download @can_download end |
#can_edit ⇒ Boolean Also known as: can_edit?
Output only. Whether the current user can edit this file. Other factors may
limit the type of changes a user can make to a file. For example, see
canChangeCopyRequiresWriterPermission or canModifyContent.
Corresponds to the JSON property canEdit
2584 2585 2586 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2584 def can_edit @can_edit end |
#can_enable_inherited_permissions ⇒ Boolean Also known as: can_enable_inherited_permissions?
Output only. Whether a user can re-enable inherited permissions.
Corresponds to the JSON property canEnableInheritedPermissions
2590 2591 2592 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2590 def @can_enable_inherited_permissions end |
#can_list_children ⇒ Boolean Also known as: can_list_children?
Output only. Whether the current user can list the children of this folder.
This is always false when the item is not a folder.
Corresponds to the JSON property canListChildren
2597 2598 2599 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2597 def can_list_children @can_list_children end |
#can_modify_content ⇒ Boolean Also known as: can_modify_content?
Output only. Whether the current user can modify the content of this file.
Corresponds to the JSON property canModifyContent
2603 2604 2605 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2603 def can_modify_content @can_modify_content end |
#can_modify_content_restriction ⇒ Boolean Also known as: can_modify_content_restriction?
Deprecated: Output only. Use one of canModifyEditorContentRestriction,
canModifyOwnerContentRestriction or canRemoveContentRestriction.
Corresponds to the JSON property canModifyContentRestriction
2610 2611 2612 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2610 def can_modify_content_restriction @can_modify_content_restriction end |
#can_modify_editor_content_restriction ⇒ Boolean Also known as: can_modify_editor_content_restriction?
Output only. Whether the current user can add or modify content restrictions
on the file which are editor restricted.
Corresponds to the JSON property canModifyEditorContentRestriction
2617 2618 2619 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2617 def can_modify_editor_content_restriction @can_modify_editor_content_restriction end |
#can_modify_labels ⇒ Boolean Also known as: can_modify_labels?
Output only. Whether the current user can modify the labels on the file.
Corresponds to the JSON property canModifyLabels
2623 2624 2625 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2623 def can_modify_labels @can_modify_labels end |
#can_modify_owner_content_restriction ⇒ Boolean Also known as: can_modify_owner_content_restriction?
Output only. Whether the current user can add or modify content restrictions
which are owner restricted.
Corresponds to the JSON property canModifyOwnerContentRestriction
2630 2631 2632 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2630 def can_modify_owner_content_restriction @can_modify_owner_content_restriction end |
#can_move_children_out_of_drive ⇒ Boolean Also known as: can_move_children_out_of_drive?
Output only. Whether the current user can move children of this folder outside
of the shared drive. This is false when the item is not a folder. Only
populated for items in shared drives.
Corresponds to the JSON property canMoveChildrenOutOfDrive
2638 2639 2640 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2638 def can_move_children_out_of_drive @can_move_children_out_of_drive end |
#can_move_children_out_of_team_drive ⇒ Boolean Also known as: can_move_children_out_of_team_drive?
Output only. Deprecated: Use canMoveChildrenOutOfDrive instead.
Corresponds to the JSON property canMoveChildrenOutOfTeamDrive
2644 2645 2646 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2644 def can_move_children_out_of_team_drive @can_move_children_out_of_team_drive end |
#can_move_children_within_drive ⇒ Boolean Also known as: can_move_children_within_drive?
Output only. Whether the current user can move children of this folder within
this drive. This is false when the item is not a folder. Note that a request
to move the child may still fail depending on the current user's access to the
child and to the destination folder.
Corresponds to the JSON property canMoveChildrenWithinDrive
2653 2654 2655 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2653 def can_move_children_within_drive @can_move_children_within_drive end |
#can_move_children_within_team_drive ⇒ Boolean Also known as: can_move_children_within_team_drive?
Output only. Deprecated: Use canMoveChildrenWithinDrive instead.
Corresponds to the JSON property canMoveChildrenWithinTeamDrive
2659 2660 2661 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2659 def can_move_children_within_team_drive @can_move_children_within_team_drive end |
#can_move_item_into_team_drive ⇒ Boolean Also known as: can_move_item_into_team_drive?
Output only. Deprecated: Use canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveItemIntoTeamDrive
2665 2666 2667 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2665 def can_move_item_into_team_drive @can_move_item_into_team_drive end |
#can_move_item_out_of_drive ⇒ Boolean Also known as: can_move_item_out_of_drive?
Output only. Whether the current user can move this item outside of this drive
by changing its parent. Note that a request to change the parent of the item
may still fail depending on the new parent that is being added.
Corresponds to the JSON property canMoveItemOutOfDrive
2673 2674 2675 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2673 def can_move_item_out_of_drive @can_move_item_out_of_drive end |
#can_move_item_out_of_team_drive ⇒ Boolean Also known as: can_move_item_out_of_team_drive?
Output only. Deprecated: Use canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveItemOutOfTeamDrive
2679 2680 2681 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2679 def can_move_item_out_of_team_drive @can_move_item_out_of_team_drive end |
#can_move_item_within_drive ⇒ Boolean Also known as: can_move_item_within_drive?
Output only. Whether the current user can move this item within this drive.
Note that a request to change the parent of the item may still fail depending
on the new parent that is being added and the parent that is being removed.
Corresponds to the JSON property canMoveItemWithinDrive
2687 2688 2689 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2687 def can_move_item_within_drive @can_move_item_within_drive end |
#can_move_item_within_team_drive ⇒ Boolean Also known as: can_move_item_within_team_drive?
Output only. Deprecated: Use canMoveItemWithinDrive instead.
Corresponds to the JSON property canMoveItemWithinTeamDrive
2693 2694 2695 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2693 def can_move_item_within_team_drive @can_move_item_within_team_drive end |
#can_move_team_drive_item ⇒ Boolean Also known as: can_move_team_drive_item?
Output only. Deprecated: Use canMoveItemWithinDrive or
canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveTeamDriveItem
2700 2701 2702 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2700 def can_move_team_drive_item @can_move_team_drive_item end |
#can_read_drive ⇒ Boolean Also known as: can_read_drive?
Output only. Whether the current user can read the shared drive to which this
file belongs. Only populated for items in shared drives.
Corresponds to the JSON property canReadDrive
2707 2708 2709 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2707 def can_read_drive @can_read_drive end |
#can_read_labels ⇒ Boolean Also known as: can_read_labels?
Output only. Whether the current user can read the labels on the file.
Corresponds to the JSON property canReadLabels
2713 2714 2715 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2713 def can_read_labels @can_read_labels end |
#can_read_revisions ⇒ Boolean Also known as: can_read_revisions?
Output only. Whether the current user can read the revisions resource of this
file. For a shared drive item, whether revisions of non-folder descendants of
this item, or this item itself if it is not a folder, can be read.
Corresponds to the JSON property canReadRevisions
2721 2722 2723 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2721 def can_read_revisions @can_read_revisions end |
#can_read_team_drive ⇒ Boolean Also known as: can_read_team_drive?
Output only. Deprecated: Use canReadDrive instead.
Corresponds to the JSON property canReadTeamDrive
2727 2728 2729 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2727 def can_read_team_drive @can_read_team_drive end |
#can_remove_children ⇒ Boolean Also known as: can_remove_children?
Output only. Whether the current user can remove children from this folder.
This is always false when the item is not a folder. For a folder in a shared
drive, use canDeleteChildren or canTrashChildren instead.
Corresponds to the JSON property canRemoveChildren
2735 2736 2737 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2735 def can_remove_children @can_remove_children end |
#can_remove_content_restriction ⇒ Boolean Also known as: can_remove_content_restriction?
Output only. Whether there is a content restriction on the file that can be
removed by the current user.
Corresponds to the JSON property canRemoveContentRestriction
2742 2743 2744 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2742 def can_remove_content_restriction @can_remove_content_restriction end |
#can_remove_my_drive_parent ⇒ Boolean Also known as: can_remove_my_drive_parent?
Output only. Whether the current user can remove a parent from the item
without adding another parent in the same request. Not populated for shared
drive files.
Corresponds to the JSON property canRemoveMyDriveParent
2750 2751 2752 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2750 def can_remove_my_drive_parent @can_remove_my_drive_parent end |
#can_rename ⇒ Boolean Also known as: can_rename?
Output only. Whether the current user can rename this file.
Corresponds to the JSON property canRename
2756 2757 2758 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2756 def can_rename @can_rename end |
#can_share ⇒ Boolean Also known as:
Output only. Whether the current user can modify the sharing settings for this
file.
Corresponds to the JSON property canShare
2763 2764 2765 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2763 def can_share @can_share end |
#can_trash ⇒ Boolean Also known as: can_trash?
Output only. Whether the current user can move this file to trash.
Corresponds to the JSON property canTrash
2769 2770 2771 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2769 def can_trash @can_trash end |
#can_trash_children ⇒ Boolean Also known as: can_trash_children?
Output only. Whether the current user can trash children of this folder. This
is false when the item is not a folder. Only populated for items in shared
drives.
Corresponds to the JSON property canTrashChildren
2777 2778 2779 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2777 def can_trash_children @can_trash_children end |
#can_untrash ⇒ Boolean Also known as: can_untrash?
Output only. Whether the current user can restore this file from trash.
Corresponds to the JSON property canUntrash
2783 2784 2785 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2783 def can_untrash @can_untrash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 |
# File 'lib/google/apis/drive_v2/classes.rb', line 2791 def update!(**args) @can_accept_ownership = args[:can_accept_ownership] if args.key?(:can_accept_ownership) @can_add_children = args[:can_add_children] if args.key?(:can_add_children) @can_add_folder_from_another_drive = args[:can_add_folder_from_another_drive] if args.key?(:can_add_folder_from_another_drive) @can_add_my_drive_parent = args[:can_add_my_drive_parent] if args.key?(:can_add_my_drive_parent) @can_change_copy_requires_writer_permission = args[:can_change_copy_requires_writer_permission] if args.key?(:can_change_copy_requires_writer_permission) @can_change_restricted_download = args[:can_change_restricted_download] if args.key?(:can_change_restricted_download) @can_change_security_update_enabled = args[:can_change_security_update_enabled] if args.key?(:can_change_security_update_enabled) @can_comment = args[:can_comment] if args.key?(:can_comment) @can_copy = args[:can_copy] if args.key?(:can_copy) @can_delete = args[:can_delete] if args.key?(:can_delete) @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children) @can_disable_inherited_permissions = args[:can_disable_inherited_permissions] if args.key?(:can_disable_inherited_permissions) @can_download = args[:can_download] if args.key?(:can_download) @can_edit = args[:can_edit] if args.key?(:can_edit) @can_enable_inherited_permissions = args[:can_enable_inherited_permissions] if args.key?(:can_enable_inherited_permissions) @can_list_children = args[:can_list_children] if args.key?(:can_list_children) @can_modify_content = args[:can_modify_content] if args.key?(:can_modify_content) @can_modify_content_restriction = args[:can_modify_content_restriction] if args.key?(:can_modify_content_restriction) @can_modify_editor_content_restriction = args[:can_modify_editor_content_restriction] if args.key?(:can_modify_editor_content_restriction) @can_modify_labels = args[:can_modify_labels] if args.key?(:can_modify_labels) @can_modify_owner_content_restriction = args[:can_modify_owner_content_restriction] if args.key?(:can_modify_owner_content_restriction) @can_move_children_out_of_drive = args[:can_move_children_out_of_drive] if args.key?(:can_move_children_out_of_drive) @can_move_children_out_of_team_drive = args[:can_move_children_out_of_team_drive] if args.key?(:can_move_children_out_of_team_drive) @can_move_children_within_drive = args[:can_move_children_within_drive] if args.key?(:can_move_children_within_drive) @can_move_children_within_team_drive = args[:can_move_children_within_team_drive] if args.key?(:can_move_children_within_team_drive) @can_move_item_into_team_drive = args[:can_move_item_into_team_drive] if args.key?(:can_move_item_into_team_drive) @can_move_item_out_of_drive = args[:can_move_item_out_of_drive] if args.key?(:can_move_item_out_of_drive) @can_move_item_out_of_team_drive = args[:can_move_item_out_of_team_drive] if args.key?(:can_move_item_out_of_team_drive) @can_move_item_within_drive = args[:can_move_item_within_drive] if args.key?(:can_move_item_within_drive) @can_move_item_within_team_drive = args[:can_move_item_within_team_drive] if args.key?(:can_move_item_within_team_drive) @can_move_team_drive_item = args[:can_move_team_drive_item] if args.key?(:can_move_team_drive_item) @can_read_drive = args[:can_read_drive] if args.key?(:can_read_drive) @can_read_labels = args[:can_read_labels] if args.key?(:can_read_labels) @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions) @can_read_team_drive = args[:can_read_team_drive] if args.key?(:can_read_team_drive) @can_remove_children = args[:can_remove_children] if args.key?(:can_remove_children) @can_remove_content_restriction = args[:can_remove_content_restriction] if args.key?(:can_remove_content_restriction) @can_remove_my_drive_parent = args[:can_remove_my_drive_parent] if args.key?(:can_remove_my_drive_parent) @can_rename = args[:can_rename] if args.key?(:can_rename) @can_share = args[:can_share] if args.key?(:can_share) @can_trash = args[:can_trash] if args.key?(:can_trash) @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children) @can_untrash = args[:can_untrash] if args.key?(:can_untrash) end |