Class: Google::Apis::DriveV2::File::ImageMediaMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Output only. Metadata about image media. This will only be present for image types, and its contents will depend on what can be parsed from the image content.

Defined Under Namespace

Classes: Location

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageMediaMetadata

Returns a new instance of ImageMediaMetadata.



2952
2953
2954
# File 'lib/google/apis/drive_v2/classes.rb', line 2952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apertureFloat

Output only. The aperture used to create the photo (f-number). Corresponds to the JSON property aperture

Returns:

  • (Float)


2847
2848
2849
# File 'lib/google/apis/drive_v2/classes.rb', line 2847

def aperture
  @aperture
end

#camera_makeString

Output only. The make of the camera used to create the photo. Corresponds to the JSON property cameraMake

Returns:

  • (String)


2852
2853
2854
# File 'lib/google/apis/drive_v2/classes.rb', line 2852

def camera_make
  @camera_make
end

#camera_modelString

Output only. The model of the camera used to create the photo. Corresponds to the JSON property cameraModel

Returns:

  • (String)


2857
2858
2859
# File 'lib/google/apis/drive_v2/classes.rb', line 2857

def camera_model
  @camera_model
end

#color_spaceString

Output only. The color space of the photo. Corresponds to the JSON property colorSpace

Returns:

  • (String)


2862
2863
2864
# File 'lib/google/apis/drive_v2/classes.rb', line 2862

def color_space
  @color_space
end

#dateString

Output only. The date and time the photo was taken (EXIF format timestamp). Corresponds to the JSON property date

Returns:

  • (String)


2867
2868
2869
# File 'lib/google/apis/drive_v2/classes.rb', line 2867

def date
  @date
end

#exposure_biasFloat

Output only. The exposure bias of the photo (APEX value). Corresponds to the JSON property exposureBias

Returns:

  • (Float)


2872
2873
2874
# File 'lib/google/apis/drive_v2/classes.rb', line 2872

def exposure_bias
  @exposure_bias
end

#exposure_modeString

Output only. The exposure mode used to create the photo. Corresponds to the JSON property exposureMode

Returns:

  • (String)


2877
2878
2879
# File 'lib/google/apis/drive_v2/classes.rb', line 2877

def exposure_mode
  @exposure_mode
end

#exposure_timeFloat

Output only. The length of the exposure, in seconds. Corresponds to the JSON property exposureTime

Returns:

  • (Float)


2882
2883
2884
# File 'lib/google/apis/drive_v2/classes.rb', line 2882

def exposure_time
  @exposure_time
end

#flash_usedBoolean Also known as: flash_used?

Output only. Whether a flash was used to create the photo. Corresponds to the JSON property flashUsed

Returns:

  • (Boolean)


2887
2888
2889
# File 'lib/google/apis/drive_v2/classes.rb', line 2887

def flash_used
  @flash_used
end

#focal_lengthFloat

Output only. The focal length used to create the photo, in millimeters. Corresponds to the JSON property focalLength

Returns:

  • (Float)


2893
2894
2895
# File 'lib/google/apis/drive_v2/classes.rb', line 2893

def focal_length
  @focal_length
end

#heightFixnum

Output only. The height of the image in pixels. Corresponds to the JSON property height

Returns:

  • (Fixnum)


2898
2899
2900
# File 'lib/google/apis/drive_v2/classes.rb', line 2898

def height
  @height
end

#iso_speedFixnum

Output only. The ISO speed used to create the photo. Corresponds to the JSON property isoSpeed

Returns:

  • (Fixnum)


2903
2904
2905
# File 'lib/google/apis/drive_v2/classes.rb', line 2903

def iso_speed
  @iso_speed
end

#lensString

Output only. The lens used to create the photo. Corresponds to the JSON property lens

Returns:

  • (String)


2908
2909
2910
# File 'lib/google/apis/drive_v2/classes.rb', line 2908

def lens
  @lens
end

#locationGoogle::Apis::DriveV2::File::ImageMediaMetadata::Location

Output only. Geographic location information stored in the image. Corresponds to the JSON property location



2913
2914
2915
# File 'lib/google/apis/drive_v2/classes.rb', line 2913

def location
  @location
end

#max_aperture_valueFloat

Output only. The smallest f-number of the lens at the focal length used to create the photo (APEX value). Corresponds to the JSON property maxApertureValue

Returns:

  • (Float)


2919
2920
2921
# File 'lib/google/apis/drive_v2/classes.rb', line 2919

def max_aperture_value
  @max_aperture_value
end

#metering_modeString

Output only. The metering mode used to create the photo. Corresponds to the JSON property meteringMode

Returns:

  • (String)


2924
2925
2926
# File 'lib/google/apis/drive_v2/classes.rb', line 2924

def metering_mode
  @metering_mode
end

#rotationFixnum

Output only. The number of clockwise 90 degree rotations applied from the image's original orientation. Corresponds to the JSON property rotation

Returns:

  • (Fixnum)


2930
2931
2932
# File 'lib/google/apis/drive_v2/classes.rb', line 2930

def rotation
  @rotation
end

#sensorString

Output only. The type of sensor used to create the photo. Corresponds to the JSON property sensor

Returns:

  • (String)


2935
2936
2937
# File 'lib/google/apis/drive_v2/classes.rb', line 2935

def sensor
  @sensor
end

#subject_distanceFixnum

Output only. The distance to the subject of the photo, in meters. Corresponds to the JSON property subjectDistance

Returns:

  • (Fixnum)


2940
2941
2942
# File 'lib/google/apis/drive_v2/classes.rb', line 2940

def subject_distance
  @subject_distance
end

#white_balanceString

Output only. The white balance mode used to create the photo. Corresponds to the JSON property whiteBalance

Returns:

  • (String)


2945
2946
2947
# File 'lib/google/apis/drive_v2/classes.rb', line 2945

def white_balance
  @white_balance
end

#widthFixnum

Output only. The width of the image in pixels. Corresponds to the JSON property width

Returns:

  • (Fixnum)


2950
2951
2952
# File 'lib/google/apis/drive_v2/classes.rb', line 2950

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/google/apis/drive_v2/classes.rb', line 2957

def update!(**args)
  @aperture = args[:aperture] if args.key?(:aperture)
  @camera_make = args[:camera_make] if args.key?(:camera_make)
  @camera_model = args[:camera_model] if args.key?(:camera_model)
  @color_space = args[:color_space] if args.key?(:color_space)
  @date = args[:date] if args.key?(:date)
  @exposure_bias = args[:exposure_bias] if args.key?(:exposure_bias)
  @exposure_mode = args[:exposure_mode] if args.key?(:exposure_mode)
  @exposure_time = args[:exposure_time] if args.key?(:exposure_time)
  @flash_used = args[:flash_used] if args.key?(:flash_used)
  @focal_length = args[:focal_length] if args.key?(:focal_length)
  @height = args[:height] if args.key?(:height)
  @iso_speed = args[:iso_speed] if args.key?(:iso_speed)
  @lens = args[:lens] if args.key?(:lens)
  @location = args[:location] if args.key?(:location)
  @max_aperture_value = args[:max_aperture_value] if args.key?(:max_aperture_value)
  @metering_mode = args[:metering_mode] if args.key?(:metering_mode)
  @rotation = args[:rotation] if args.key?(:rotation)
  @sensor = args[:sensor] if args.key?(:sensor)
  @subject_distance = args[:subject_distance] if args.key?(:subject_distance)
  @white_balance = args[:white_balance] if args.key?(:white_balance)
  @width = args[:width] if args.key?(:width)
end