Class: Google::Apis::DriveV2::File::Labels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A group of labels for the file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Labels

Returns a new instance of Labels.



3093
3094
3095
# File 'lib/google/apis/drive_v2/classes.rb', line 3093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hiddenBoolean Also known as: hidden?

Output only. Deprecated. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


3059
3060
3061
# File 'lib/google/apis/drive_v2/classes.rb', line 3059

def hidden
  @hidden
end

#modifiedBoolean Also known as: modified?

Output only. Whether the file has been modified by this user. Corresponds to the JSON property modified

Returns:

  • (Boolean)


3065
3066
3067
# File 'lib/google/apis/drive_v2/classes.rb', line 3065

def modified
  @modified
end

#restrictedBoolean Also known as: restricted?

Output only. Deprecated: Use copyRequiresWriterPermission instead. Corresponds to the JSON property restricted

Returns:

  • (Boolean)


3071
3072
3073
# File 'lib/google/apis/drive_v2/classes.rb', line 3071

def restricted
  @restricted
end

#starredBoolean Also known as: starred?

Whether this file is starred by the user. Corresponds to the JSON property starred

Returns:

  • (Boolean)


3077
3078
3079
# File 'lib/google/apis/drive_v2/classes.rb', line 3077

def starred
  @starred
end

#trashedBoolean Also known as: trashed?

Whether this file has been trashed. This label applies to all users accessing the file; however, only owners are allowed to see and untrash files. Corresponds to the JSON property trashed

Returns:

  • (Boolean)


3084
3085
3086
# File 'lib/google/apis/drive_v2/classes.rb', line 3084

def trashed
  @trashed
end

#viewedBoolean Also known as: viewed?

Whether this file has been viewed by this user. Corresponds to the JSON property viewed

Returns:

  • (Boolean)


3090
3091
3092
# File 'lib/google/apis/drive_v2/classes.rb', line 3090

def viewed
  @viewed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3098
3099
3100
3101
3102
3103
3104
3105
# File 'lib/google/apis/drive_v2/classes.rb', line 3098

def update!(**args)
  @hidden = args[:hidden] if args.key?(:hidden)
  @modified = args[:modified] if args.key?(:modified)
  @restricted = args[:restricted] if args.key?(:restricted)
  @starred = args[:starred] if args.key?(:starred)
  @trashed = args[:trashed] if args.key?(:trashed)
  @viewed = args[:viewed] if args.key?(:viewed)
end