Class: Google::Apis::DriveV2::File::ShortcutDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Shortcut file details. Only populated for shortcut files, which have the mimeType field set to application/vnd.google-apps.shortcut. Can only be set on files.insert requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShortcutDetails

Returns a new instance of ShortcutDetails.



3160
3161
3162
# File 'lib/google/apis/drive_v2/classes.rb', line 3160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_idString

The ID of the file that this shortcut points to. Can only be set on files. insert requests. Corresponds to the JSON property targetId

Returns:

  • (String)


3146
3147
3148
# File 'lib/google/apis/drive_v2/classes.rb', line 3146

def target_id
  @target_id
end

#target_mime_typeString

Output only. The MIME type of the file that this shortcut points to. The value of this field is a snapshot of the target's MIME type, captured when the shortcut is created. Corresponds to the JSON property targetMimeType

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/drive_v2/classes.rb', line 3153

def target_mime_type
  @target_mime_type
end

#target_resource_keyString

Output only. The ResourceKey for the target file. Corresponds to the JSON property targetResourceKey

Returns:

  • (String)


3158
3159
3160
# File 'lib/google/apis/drive_v2/classes.rb', line 3158

def target_resource_key
  @target_resource_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3165
3166
3167
3168
3169
# File 'lib/google/apis/drive_v2/classes.rb', line 3165

def update!(**args)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_mime_type = args[:target_mime_type] if args.key?(:target_mime_type)
  @target_resource_key = args[:target_resource_key] if args.key?(:target_resource_key)
end