Class: Google::Apis::DriveV2::FileList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of files.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileList

Returns a new instance of FileList.



3281
3282
3283
# File 'lib/google/apis/drive_v2/classes.rb', line 3281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The ETag of the list. Corresponds to the JSON property etag

Returns:

  • (String)


3240
3241
3242
# File 'lib/google/apis/drive_v2/classes.rb', line 3240

def etag
  @etag
end

#incomplete_searchBoolean Also known as: incomplete_search?

Whether the search process was incomplete. If true, then some search results may be missing, since all documents were not searched. This may occur when searching multiple drives with the "allDrives" corpora, but all corpora could not be searched. When this happens, it is suggested that clients narrow their query by choosing a different corpus such as "default" or "drive". Corresponds to the JSON property incompleteSearch

Returns:

  • (Boolean)


3249
3250
3251
# File 'lib/google/apis/drive_v2/classes.rb', line 3249

def incomplete_search
  @incomplete_search
end

#itemsArray<Google::Apis::DriveV2::File>

The list of files. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items

Returns:



3256
3257
3258
# File 'lib/google/apis/drive_v2/classes.rb', line 3256

def items
  @items
end

#kindString

This is always drive#fileList. Corresponds to the JSON property kind

Returns:

  • (String)


3261
3262
3263
# File 'lib/google/apis/drive_v2/classes.rb', line 3261

def kind
  @kind
end

A link to the next page of files. Corresponds to the JSON property nextLink

Returns:

  • (String)


3266
3267
3268
# File 'lib/google/apis/drive_v2/classes.rb', line 3266

def next_link
  @next_link
end

#next_page_tokenString

The page token for the next page of files. This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3274
3275
3276
# File 'lib/google/apis/drive_v2/classes.rb', line 3274

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


3279
3280
3281
# File 'lib/google/apis/drive_v2/classes.rb', line 3279

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3286
3287
3288
3289
3290
3291
3292
3293
3294
# File 'lib/google/apis/drive_v2/classes.rb', line 3286

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @incomplete_search = args[:incomplete_search] if args.key?(:incomplete_search)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_link = args[:next_link] if args.key?(:next_link)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end