Class: Google::Apis::DriveV2::PermissionList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of permissions associated with a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PermissionList

Returns a new instance of PermissionList.



4071
4072
4073
# File 'lib/google/apis/drive_v2/classes.rb', line 4071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The ETag of the list. Corresponds to the JSON property etag

Returns:

  • (String)


4046
4047
4048
# File 'lib/google/apis/drive_v2/classes.rb', line 4046

def etag
  @etag
end

#itemsArray<Google::Apis::DriveV2::Permission>

The list of permissions. Corresponds to the JSON property items



4051
4052
4053
# File 'lib/google/apis/drive_v2/classes.rb', line 4051

def items
  @items
end

#kindString

This is always drive#permissionList. Corresponds to the JSON property kind

Returns:

  • (String)


4056
4057
4058
# File 'lib/google/apis/drive_v2/classes.rb', line 4056

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of permissions. This field will be absent if the end of the permissions list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/drive_v2/classes.rb', line 4064

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/drive_v2/classes.rb', line 4069

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4076
4077
4078
4079
4080
4081
4082
# File 'lib/google/apis/drive_v2/classes.rb', line 4076

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end