Class: Google::Apis::DriveV2::Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A revision of a file. Some resource methods (such as revisions.update) require a revisionId. Use the revisions.list method to retrieve the ID for a revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Revision

Returns a new instance of Revision.



4295
4296
4297
# File 'lib/google/apis/drive_v2/classes.rb', line 4295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#download_urlString

Output only. Short term download URL for the file. This will only be populated on files with content stored in Drive. Corresponds to the JSON property downloadUrl

Returns:

  • (String)


4191
4192
4193
# File 'lib/google/apis/drive_v2/classes.rb', line 4191

def download_url
  @download_url
end

#etagString

Output only. The ETag of the revision. Corresponds to the JSON property etag

Returns:

  • (String)


4196
4197
4198
# File 'lib/google/apis/drive_v2/classes.rb', line 4196

def etag
  @etag
end

Output only. Links for exporting Docs Editors files to specific formats. Corresponds to the JSON property exportLinks

Returns:

  • (Hash<String,String>)


4201
4202
4203
# File 'lib/google/apis/drive_v2/classes.rb', line 4201

def export_links
  @export_links
end

#file_sizeFixnum

Output only. The size of the revision in bytes. This will only be populated on files with content stored in Drive. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


4207
4208
4209
# File 'lib/google/apis/drive_v2/classes.rb', line 4207

def file_size
  @file_size
end

#idString

Output only. The ID of the revision. Corresponds to the JSON property id

Returns:

  • (String)


4212
4213
4214
# File 'lib/google/apis/drive_v2/classes.rb', line 4212

def id
  @id
end

#kindString

Output only. This is always drive#revision. Corresponds to the JSON property kind

Returns:

  • (String)


4217
4218
4219
# File 'lib/google/apis/drive_v2/classes.rb', line 4217

def kind
  @kind
end

#last_modifying_userGoogle::Apis::DriveV2::User

Information about a Drive user. Corresponds to the JSON property lastModifyingUser



4222
4223
4224
# File 'lib/google/apis/drive_v2/classes.rb', line 4222

def last_modifying_user
  @last_modifying_user
end

#last_modifying_user_nameString

Output only. Name of the last user to modify this revision. Corresponds to the JSON property lastModifyingUserName

Returns:

  • (String)


4227
4228
4229
# File 'lib/google/apis/drive_v2/classes.rb', line 4227

def last_modifying_user_name
  @last_modifying_user_name
end

#md5_checksumString

Output only. An MD5 checksum for the content of this revision. This will only be populated on files with content stored in Drive. Corresponds to the JSON property md5Checksum

Returns:

  • (String)


4233
4234
4235
# File 'lib/google/apis/drive_v2/classes.rb', line 4233

def md5_checksum
  @md5_checksum
end

#mime_typeString

Output only. The MIME type of the revision. Corresponds to the JSON property mimeType

Returns:

  • (String)


4238
4239
4240
# File 'lib/google/apis/drive_v2/classes.rb', line 4238

def mime_type
  @mime_type
end

#modified_dateDateTime

Last time this revision was modified (formatted RFC 3339 timestamp). Corresponds to the JSON property modifiedDate

Returns:

  • (DateTime)


4243
4244
4245
# File 'lib/google/apis/drive_v2/classes.rb', line 4243

def modified_date
  @modified_date
end

#original_filenameString

Output only. The original filename when this revision was created. This will only be populated on files with content stored in Drive. Corresponds to the JSON property originalFilename

Returns:

  • (String)


4249
4250
4251
# File 'lib/google/apis/drive_v2/classes.rb', line 4249

def original_filename
  @original_filename
end

#pinnedBoolean Also known as: pinned?

Whether this revision is pinned to prevent automatic purging. If not set, the revision is automatically purged 30 days after newer content is uploaded. This field can only be modified on files with content stored in Drive, excluding Docs Editors files. Revisions can also be pinned when they are created through the drive.files.insert/update/copy by using the pinned query parameter. Pinned revisions are stored indefinitely using additional storage quota, up to a maximum of 200 revisions. Corresponds to the JSON property pinned

Returns:

  • (Boolean)


4260
4261
4262
# File 'lib/google/apis/drive_v2/classes.rb', line 4260

def pinned
  @pinned
end

#publish_autoBoolean Also known as: publish_auto?

Whether subsequent revisions will be automatically republished. This is only populated and can only be modified for Docs Editors files. Corresponds to the JSON property publishAuto

Returns:

  • (Boolean)


4267
4268
4269
# File 'lib/google/apis/drive_v2/classes.rb', line 4267

def publish_auto
  @publish_auto
end

#publishedBoolean Also known as: published?

Whether this revision is published. This is only populated and can only be modified for Docs Editors files. Corresponds to the JSON property published

Returns:

  • (Boolean)


4274
4275
4276
# File 'lib/google/apis/drive_v2/classes.rb', line 4274

def published
  @published
end

Output only. A link to the published revision. This is only populated for Docs Editors files. Corresponds to the JSON property publishedLink

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/drive_v2/classes.rb', line 4281

def published_link
  @published_link
end

#published_outside_domainBoolean Also known as: published_outside_domain?

Whether this revision is published outside the domain. This is only populated and can only be modified for Docs Editors files. Corresponds to the JSON property publishedOutsideDomain

Returns:

  • (Boolean)


4287
4288
4289
# File 'lib/google/apis/drive_v2/classes.rb', line 4287

def published_outside_domain
  @published_outside_domain
end

Output only. A link back to this revision. Corresponds to the JSON property selfLink

Returns:

  • (String)


4293
4294
4295
# File 'lib/google/apis/drive_v2/classes.rb', line 4293

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
# File 'lib/google/apis/drive_v2/classes.rb', line 4300

def update!(**args)
  @download_url = args[:download_url] if args.key?(:download_url)
  @etag = args[:etag] if args.key?(:etag)
  @export_links = args[:export_links] if args.key?(:export_links)
  @file_size = args[:file_size] if args.key?(:file_size)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modifying_user = args[:last_modifying_user] if args.key?(:last_modifying_user)
  @last_modifying_user_name = args[:last_modifying_user_name] if args.key?(:last_modifying_user_name)
  @md5_checksum = args[:md5_checksum] if args.key?(:md5_checksum)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @modified_date = args[:modified_date] if args.key?(:modified_date)
  @original_filename = args[:original_filename] if args.key?(:original_filename)
  @pinned = args[:pinned] if args.key?(:pinned)
  @publish_auto = args[:publish_auto] if args.key?(:publish_auto)
  @published = args[:published] if args.key?(:published)
  @published_link = args[:published_link] if args.key?(:published_link)
  @published_outside_domain = args[:published_outside_domain] if args.key?(:published_outside_domain)
  @self_link = args[:self_link] if args.key?(:self_link)
end