Class: Google::Apis::DriveV2::RevisionList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

A list of revisions of a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevisionList

Returns a new instance of RevisionList.



4355
4356
4357
# File 'lib/google/apis/drive_v2/classes.rb', line 4355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The ETag of the list. Corresponds to the JSON property etag

Returns:

  • (String)


4329
4330
4331
# File 'lib/google/apis/drive_v2/classes.rb', line 4329

def etag
  @etag
end

#itemsArray<Google::Apis::DriveV2::Revision>

The list of revisions. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items



4335
4336
4337
# File 'lib/google/apis/drive_v2/classes.rb', line 4335

def items
  @items
end

#kindString

This is always drive#revisionList. Corresponds to the JSON property kind

Returns:

  • (String)


4340
4341
4342
# File 'lib/google/apis/drive_v2/classes.rb', line 4340

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of revisions. This field will be absent if the end of the revisions list has been reached. If the token is rejected for any reason, it should be discarded and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4348
4349
4350
# File 'lib/google/apis/drive_v2/classes.rb', line 4348

def next_page_token
  @next_page_token
end

A link back to this list. Corresponds to the JSON property selfLink

Returns:

  • (String)


4353
4354
4355
# File 'lib/google/apis/drive_v2/classes.rb', line 4353

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4360
4361
4362
4363
4364
4365
4366
# File 'lib/google/apis/drive_v2/classes.rb', line 4360

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end