Class: Google::Apis::DriveV2::TeamDrive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Deprecated: Use the drive collection instead.

Defined Under Namespace

Classes: BackgroundImageFile, Capabilities, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeamDrive

Returns a new instance of TeamDrive.



4467
4468
4469
# File 'lib/google/apis/drive_v2/classes.rb', line 4467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_fileGoogle::Apis::DriveV2::TeamDrive::BackgroundImageFile

An image file and cropping parameters from which a background image for this Team Drive is set. This is a write only field; it can only be set on drive. teamdrives.update requests that don't set themeId. When specified, all fields of the backgroundImageFile must be set. Corresponds to the JSON property backgroundImageFile



4405
4406
4407
# File 'lib/google/apis/drive_v2/classes.rb', line 4405

def background_image_file
  @background_image_file
end

A short-lived link to this Team Drive's background image. Corresponds to the JSON property backgroundImageLink

Returns:

  • (String)


4410
4411
4412
# File 'lib/google/apis/drive_v2/classes.rb', line 4410

def background_image_link
  @background_image_link
end

#capabilitiesGoogle::Apis::DriveV2::TeamDrive::Capabilities

Capabilities the current user has on this Team Drive. Corresponds to the JSON property capabilities



4415
4416
4417
# File 'lib/google/apis/drive_v2/classes.rb', line 4415

def capabilities
  @capabilities
end

#color_rgbString

The color of this Team Drive as an RGB hex string. It can only be set on a drive.teamdrives.update request that does not set themeId. Corresponds to the JSON property colorRgb

Returns:

  • (String)


4421
4422
4423
# File 'lib/google/apis/drive_v2/classes.rb', line 4421

def color_rgb
  @color_rgb
end

#created_dateDateTime

The time at which the Team Drive was created (RFC 3339 date-time). Corresponds to the JSON property createdDate

Returns:

  • (DateTime)


4426
4427
4428
# File 'lib/google/apis/drive_v2/classes.rb', line 4426

def created_date
  @created_date
end

#idString

The ID of this Team Drive which is also the ID of the top level folder of this Team Drive. Corresponds to the JSON property id

Returns:

  • (String)


4432
4433
4434
# File 'lib/google/apis/drive_v2/classes.rb', line 4432

def id
  @id
end

#kindString

This is always drive#teamDrive Corresponds to the JSON property kind

Returns:

  • (String)


4437
4438
4439
# File 'lib/google/apis/drive_v2/classes.rb', line 4437

def kind
  @kind
end

#nameString

The name of this Team Drive. Corresponds to the JSON property name

Returns:

  • (String)


4442
4443
4444
# File 'lib/google/apis/drive_v2/classes.rb', line 4442

def name
  @name
end

#org_unit_idString

The organizational unit of this shared drive. This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


4449
4450
4451
# File 'lib/google/apis/drive_v2/classes.rb', line 4449

def org_unit_id
  @org_unit_id
end

#restrictionsGoogle::Apis::DriveV2::TeamDrive::Restrictions

A set of restrictions that apply to this Team Drive or items inside this Team Drive. Corresponds to the JSON property restrictions



4455
4456
4457
# File 'lib/google/apis/drive_v2/classes.rb', line 4455

def restrictions
  @restrictions
end

#theme_idString

The ID of the theme from which the background image and color will be set. The set of possible teamDriveThemes can be retrieved from a drive.about.get response. When not specified on a drive.teamdrives.insert request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set colorRgb or backgroundImageFile. Corresponds to the JSON property themeId

Returns:

  • (String)


4465
4466
4467
# File 'lib/google/apis/drive_v2/classes.rb', line 4465

def theme_id
  @theme_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4472
4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
4484
# File 'lib/google/apis/drive_v2/classes.rb', line 4472

def update!(**args)
  @background_image_file = args[:background_image_file] if args.key?(:background_image_file)
  @background_image_link = args[:background_image_link] if args.key?(:background_image_link)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @color_rgb = args[:color_rgb] if args.key?(:color_rgb)
  @created_date = args[:created_date] if args.key?(:created_date)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @theme_id = args[:theme_id] if args.key?(:theme_id)
end