Class: Google::Apis::DriveV2::TeamDrive::BackgroundImageFile
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::TeamDrive::BackgroundImageFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
An image file and cropping parameters from which a background image for this
Team Drive is set. This is a write only field; it can only be set on drive.
teamdrives.update requests that don't set themeId. When specified, all
fields of the backgroundImageFile must be set.
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of an image file in Drive to use for the background image.
-
#width ⇒ Float
The width of the cropped image in the closed range of 0 to 1.
-
#x_coordinate ⇒ Float
The X coordinate of the upper left corner of the cropping area in the background image.
-
#y_coordinate ⇒ Float
The Y coordinate of the upper left corner of the cropping area in the background image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackgroundImageFile
constructor
A new instance of BackgroundImageFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackgroundImageFile
Returns a new instance of BackgroundImageFile.
4523 4524 4525 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The ID of an image file in Drive to use for the background image.
Corresponds to the JSON property id
4496 4497 4498 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4496 def id @id end |
#width ⇒ Float
The width of the cropped image in the closed range of 0 to 1. This value
represents the width of the cropped image divided by the width of the entire
image. The height is computed by applying a width to height aspect ratio of 80
to 9. The resulting image must be at least 1280 pixels wide and 144 pixels
high.
Corresponds to the JSON property width
4505 4506 4507 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4505 def width @width end |
#x_coordinate ⇒ Float
The X coordinate of the upper left corner of the cropping area in the
background image. This is a value in the closed range of 0 to 1. This value
represents the horizontal distance from the left side of the entire image to
the left side of the cropping area divided by the width of the entire image.
Corresponds to the JSON property xCoordinate
4513 4514 4515 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4513 def x_coordinate @x_coordinate end |
#y_coordinate ⇒ Float
The Y coordinate of the upper left corner of the cropping area in the
background image. This is a value in the closed range of 0 to 1. This value
represents the vertical distance from the top side of the entire image to the
top side of the cropping area divided by the height of the entire image.
Corresponds to the JSON property yCoordinate
4521 4522 4523 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4521 def y_coordinate @y_coordinate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4528 4529 4530 4531 4532 4533 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4528 def update!(**args) @id = args[:id] if args.key?(:id) @width = args[:width] if args.key?(:width) @x_coordinate = args[:x_coordinate] if args.key?(:x_coordinate) @y_coordinate = args[:y_coordinate] if args.key?(:y_coordinate) end |