Class: Google::Apis::DriveV2::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb

Overview

Information about a Drive user.

Defined Under Namespace

Classes: Picture

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



4831
4832
4833
# File 'lib/google/apis/drive_v2/classes.rb', line 4831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. A plain text displayable name for this user. Corresponds to the JSON property displayName

Returns:

  • (String)


4800
4801
4802
# File 'lib/google/apis/drive_v2/classes.rb', line 4800

def display_name
  @display_name
end

#email_addressString

Output only. The email address of the user. This may not be present in certain contexts if the user has not made their email address visible to the requester. Corresponds to the JSON property emailAddress

Returns:

  • (String)


4806
4807
4808
# File 'lib/google/apis/drive_v2/classes.rb', line 4806

def email_address
  @email_address
end

#is_authenticated_userBoolean Also known as: is_authenticated_user?

Output only. Whether this user is the same as the authenticated user for whom the request was made. Corresponds to the JSON property isAuthenticatedUser

Returns:

  • (Boolean)


4812
4813
4814
# File 'lib/google/apis/drive_v2/classes.rb', line 4812

def is_authenticated_user
  @is_authenticated_user
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string drive#user. Corresponds to the JSON property kind

Returns:

  • (String)


4819
4820
4821
# File 'lib/google/apis/drive_v2/classes.rb', line 4819

def kind
  @kind
end

#permission_idString

Output only. The user's ID as visible in Permission resources. Corresponds to the JSON property permissionId

Returns:

  • (String)


4824
4825
4826
# File 'lib/google/apis/drive_v2/classes.rb', line 4824

def permission_id
  @permission_id
end

#pictureGoogle::Apis::DriveV2::User::Picture

Output only. The user's profile picture. Corresponds to the JSON property picture



4829
4830
4831
# File 'lib/google/apis/drive_v2/classes.rb', line 4829

def picture
  @picture
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4836
4837
4838
4839
4840
4841
4842
4843
# File 'lib/google/apis/drive_v2/classes.rb', line 4836

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email_address = args[:email_address] if args.key?(:email_address)
  @is_authenticated_user = args[:is_authenticated_user] if args.key?(:is_authenticated_user)
  @kind = args[:kind] if args.key?(:kind)
  @permission_id = args[:permission_id] if args.key?(:permission_id)
  @picture = args[:picture] if args.key?(:picture)
end