Class: Google::Apis::DriveV2::App
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::App
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
The apps resource provides a list of the apps that a user has installed, with
information about each app's supported MIME types, file extensions, and other
details. Some resource methods (such as apps.get) require an appId. Use
the apps.list method to retrieve the ID for an installed application.
Defined Under Namespace
Classes: Icon
Instance Attribute Summary collapse
-
#authorized ⇒ Boolean
(also: #authorized?)
Whether the app is authorized to access data on the user's Drive.
-
#create_in_folder_template ⇒ String
The template url to create a new file with this app in a given folder.
-
#create_url ⇒ String
The url to create a new file with this app.
-
#has_drive_wide_scope ⇒ Boolean
(also: #has_drive_wide_scope?)
Whether the app has drive-wide scope.
-
#icons ⇒ Array<Google::Apis::DriveV2::App::Icon>
The various icons for the app.
-
#id ⇒ String
The ID of the app.
-
#installed ⇒ Boolean
(also: #installed?)
Whether the app is installed.
-
#kind ⇒ String
This is always
drive#app. -
#long_description ⇒ String
A long description of the app.
-
#name ⇒ String
The name of the app.
-
#object_type ⇒ String
The type of object this app creates (e.g. Chart).
-
#open_url_template ⇒ String
The template url for opening files with this app.
-
#primary_file_extensions ⇒ Array<String>
The list of primary file extensions.
-
#primary_mime_types ⇒ Array<String>
The list of primary mime types.
-
#product_id ⇒ String
The ID of the product listing for this app.
-
#product_url ⇒ String
A link to the product listing for this app.
-
#secondary_file_extensions ⇒ Array<String>
The list of secondary file extensions.
-
#secondary_mime_types ⇒ Array<String>
The list of secondary mime types.
-
#short_description ⇒ String
A short description of the app.
-
#supports_create ⇒ Boolean
(also: #supports_create?)
Whether this app supports creating new objects.
-
#supports_import ⇒ Boolean
(also: #supports_import?)
Whether this app supports importing from Docs Editors.
-
#supports_multi_open ⇒ Boolean
(also: #supports_multi_open?)
Whether this app supports opening more than one file.
-
#supports_offline_create ⇒ Boolean
(also: #supports_offline_create?)
Whether this app supports creating new files when offline.
-
#use_by_default ⇒ Boolean
(also: #use_by_default?)
Whether the app is selected as the default handler for the types it supports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ App
constructor
A new instance of App.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ App
Returns a new instance of App.
599 600 601 |
# File 'lib/google/apis/drive_v2/classes.rb', line 599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized ⇒ Boolean Also known as:
Whether the app is authorized to access data on the user's Drive.
Corresponds to the JSON property authorized
468 469 470 |
# File 'lib/google/apis/drive_v2/classes.rb', line 468 def @authorized end |
#create_in_folder_template ⇒ String
The template url to create a new file with this app in a given folder. The
template will contain folderId to be replaced by the folder to create the
new file in.
Corresponds to the JSON property createInFolderTemplate
476 477 478 |
# File 'lib/google/apis/drive_v2/classes.rb', line 476 def create_in_folder_template @create_in_folder_template end |
#create_url ⇒ String
The url to create a new file with this app.
Corresponds to the JSON property createUrl
481 482 483 |
# File 'lib/google/apis/drive_v2/classes.rb', line 481 def create_url @create_url end |
#has_drive_wide_scope ⇒ Boolean Also known as: has_drive_wide_scope?
Whether the app has drive-wide scope. An app with drive-wide scope can access
all files in the user's drive.
Corresponds to the JSON property hasDriveWideScope
487 488 489 |
# File 'lib/google/apis/drive_v2/classes.rb', line 487 def has_drive_wide_scope @has_drive_wide_scope end |
#icons ⇒ Array<Google::Apis::DriveV2::App::Icon>
The various icons for the app.
Corresponds to the JSON property icons
493 494 495 |
# File 'lib/google/apis/drive_v2/classes.rb', line 493 def icons @icons end |
#id ⇒ String
The ID of the app.
Corresponds to the JSON property id
498 499 500 |
# File 'lib/google/apis/drive_v2/classes.rb', line 498 def id @id end |
#installed ⇒ Boolean Also known as: installed?
Whether the app is installed.
Corresponds to the JSON property installed
503 504 505 |
# File 'lib/google/apis/drive_v2/classes.rb', line 503 def installed @installed end |
#kind ⇒ String
This is always drive#app.
Corresponds to the JSON property kind
509 510 511 |
# File 'lib/google/apis/drive_v2/classes.rb', line 509 def kind @kind end |
#long_description ⇒ String
A long description of the app.
Corresponds to the JSON property longDescription
514 515 516 |
# File 'lib/google/apis/drive_v2/classes.rb', line 514 def long_description @long_description end |
#name ⇒ String
The name of the app.
Corresponds to the JSON property name
519 520 521 |
# File 'lib/google/apis/drive_v2/classes.rb', line 519 def name @name end |
#object_type ⇒ String
The type of object this app creates (e.g. Chart). If empty, the app name
should be used instead.
Corresponds to the JSON property objectType
525 526 527 |
# File 'lib/google/apis/drive_v2/classes.rb', line 525 def object_type @object_type end |
#open_url_template ⇒ String
The template url for opening files with this app. The template will contain
ids and/or exportIds to be replaced by the actual file ids. See Open
Files for the full documentation.
Corresponds to the JSON property openUrlTemplate
532 533 534 |
# File 'lib/google/apis/drive_v2/classes.rb', line 532 def open_url_template @open_url_template end |
#primary_file_extensions ⇒ Array<String>
The list of primary file extensions.
Corresponds to the JSON property primaryFileExtensions
537 538 539 |
# File 'lib/google/apis/drive_v2/classes.rb', line 537 def primary_file_extensions @primary_file_extensions end |
#primary_mime_types ⇒ Array<String>
The list of primary mime types.
Corresponds to the JSON property primaryMimeTypes
542 543 544 |
# File 'lib/google/apis/drive_v2/classes.rb', line 542 def primary_mime_types @primary_mime_types end |
#product_id ⇒ String
The ID of the product listing for this app.
Corresponds to the JSON property productId
547 548 549 |
# File 'lib/google/apis/drive_v2/classes.rb', line 547 def product_id @product_id end |
#product_url ⇒ String
A link to the product listing for this app.
Corresponds to the JSON property productUrl
552 553 554 |
# File 'lib/google/apis/drive_v2/classes.rb', line 552 def product_url @product_url end |
#secondary_file_extensions ⇒ Array<String>
The list of secondary file extensions.
Corresponds to the JSON property secondaryFileExtensions
557 558 559 |
# File 'lib/google/apis/drive_v2/classes.rb', line 557 def secondary_file_extensions @secondary_file_extensions end |
#secondary_mime_types ⇒ Array<String>
The list of secondary mime types.
Corresponds to the JSON property secondaryMimeTypes
562 563 564 |
# File 'lib/google/apis/drive_v2/classes.rb', line 562 def secondary_mime_types @secondary_mime_types end |
#short_description ⇒ String
A short description of the app.
Corresponds to the JSON property shortDescription
567 568 569 |
# File 'lib/google/apis/drive_v2/classes.rb', line 567 def short_description @short_description end |
#supports_create ⇒ Boolean Also known as: supports_create?
Whether this app supports creating new objects.
Corresponds to the JSON property supportsCreate
572 573 574 |
# File 'lib/google/apis/drive_v2/classes.rb', line 572 def supports_create @supports_create end |
#supports_import ⇒ Boolean Also known as: supports_import?
Whether this app supports importing from Docs Editors.
Corresponds to the JSON property supportsImport
578 579 580 |
# File 'lib/google/apis/drive_v2/classes.rb', line 578 def supports_import @supports_import end |
#supports_multi_open ⇒ Boolean Also known as: supports_multi_open?
Whether this app supports opening more than one file.
Corresponds to the JSON property supportsMultiOpen
584 585 586 |
# File 'lib/google/apis/drive_v2/classes.rb', line 584 def supports_multi_open @supports_multi_open end |
#supports_offline_create ⇒ Boolean Also known as: supports_offline_create?
Whether this app supports creating new files when offline.
Corresponds to the JSON property supportsOfflineCreate
590 591 592 |
# File 'lib/google/apis/drive_v2/classes.rb', line 590 def supports_offline_create @supports_offline_create end |
#use_by_default ⇒ Boolean Also known as: use_by_default?
Whether the app is selected as the default handler for the types it supports.
Corresponds to the JSON property useByDefault
596 597 598 |
# File 'lib/google/apis/drive_v2/classes.rb', line 596 def use_by_default @use_by_default end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/google/apis/drive_v2/classes.rb', line 604 def update!(**args) @authorized = args[:authorized] if args.key?(:authorized) @create_in_folder_template = args[:create_in_folder_template] if args.key?(:create_in_folder_template) @create_url = args[:create_url] if args.key?(:create_url) @has_drive_wide_scope = args[:has_drive_wide_scope] if args.key?(:has_drive_wide_scope) @icons = args[:icons] if args.key?(:icons) @id = args[:id] if args.key?(:id) @installed = args[:installed] if args.key?(:installed) @kind = args[:kind] if args.key?(:kind) @long_description = args[:long_description] if args.key?(:long_description) @name = args[:name] if args.key?(:name) @object_type = args[:object_type] if args.key?(:object_type) @open_url_template = args[:open_url_template] if args.key?(:open_url_template) @primary_file_extensions = args[:primary_file_extensions] if args.key?(:primary_file_extensions) @primary_mime_types = args[:primary_mime_types] if args.key?(:primary_mime_types) @product_id = args[:product_id] if args.key?(:product_id) @product_url = args[:product_url] if args.key?(:product_url) @secondary_file_extensions = args[:secondary_file_extensions] if args.key?(:secondary_file_extensions) @secondary_mime_types = args[:secondary_mime_types] if args.key?(:secondary_mime_types) @short_description = args[:short_description] if args.key?(:short_description) @supports_create = args[:supports_create] if args.key?(:supports_create) @supports_import = args[:supports_import] if args.key?(:supports_import) @supports_multi_open = args[:supports_multi_open] if args.key?(:supports_multi_open) @supports_offline_create = args[:supports_offline_create] if args.key?(:supports_offline_create) @use_by_default = args[:use_by_default] if args.key?(:use_by_default) end |