Class: Google::Apis::DriveV2::File::LinkShareMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::File::LinkShareMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
Contains details about the link URLs that clients are using to refer to this item.
Instance Attribute Summary collapse
-
#security_update_eligible ⇒ Boolean
(also: #security_update_eligible?)
Output only.
-
#security_update_enabled ⇒ Boolean
(also: #security_update_enabled?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkShareMetadata
constructor
A new instance of LinkShareMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkShareMetadata
Returns a new instance of LinkShareMetadata.
3125 3126 3127 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#security_update_eligible ⇒ Boolean Also known as: security_update_eligible?
Output only. Whether the file is eligible for security update.
Corresponds to the JSON property securityUpdateEligible
3116 3117 3118 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3116 def security_update_eligible @security_update_eligible end |
#security_update_enabled ⇒ Boolean Also known as: security_update_enabled?
Output only. Whether the security update is enabled for this file.
Corresponds to the JSON property securityUpdateEnabled
3122 3123 3124 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3122 def security_update_enabled @security_update_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3130 3131 3132 3133 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3130 def update!(**args) @security_update_eligible = args[:security_update_eligible] if args.key?(:security_update_eligible) @security_update_enabled = args[:security_update_enabled] if args.key?(:security_update_enabled) end |