Class: Google::Apis::DriveV2::LabelList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::LabelList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
A list of labels applied to a file.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DriveV2::Label>
The list of labels.
-
#kind ⇒ String
This is always
drive#labelListCorresponds to the JSON propertykind. -
#next_page_token ⇒ String
The page token for the next page of labels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LabelList
constructor
A new instance of LabelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LabelList
Returns a new instance of LabelList.
3558 3559 3560 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DriveV2::Label>
The list of labels.
Corresponds to the JSON property items
3543 3544 3545 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3543 def items @items end |
#kind ⇒ String
This is always drive#labelList
Corresponds to the JSON property kind
3548 3549 3550 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3548 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of labels. This field will be absent if the
end of the list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results.
Corresponds to the JSON property nextPageToken
3556 3557 3558 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3556 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3563 3564 3565 3566 3567 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3563 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |