Class: Google::Apis::DriveV2::Permission::PermissionDetail
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::Permission::PermissionDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Instance Attribute Summary collapse
-
#additional_roles ⇒ Array<String>
Output only.
-
#inherited ⇒ Boolean
(also: #inherited?)
Output only.
-
#inherited_from ⇒ String
Output only.
-
#permission_type ⇒ String
Output only.
-
#role ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PermissionDetail
constructor
A new instance of PermissionDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PermissionDetail
Returns a new instance of PermissionDetail.
3955 3956 3957 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_roles ⇒ Array<String>
Output only. Additional roles for this user. Only commenter is currently
possible, though more may be supported in the future.
Corresponds to the JSON property additionalRoles
3927 3928 3929 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3927 def additional_roles @additional_roles end |
#inherited ⇒ Boolean Also known as: inherited?
Output only. Whether this permission is inherited. This field is always
populated.
Corresponds to the JSON property inherited
3933 3934 3935 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3933 def inherited @inherited end |
#inherited_from ⇒ String
Output only. The ID of the item from which this permission is inherited. This
is only populated for items in shared drives.
Corresponds to the JSON property inheritedFrom
3940 3941 3942 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3940 def inherited_from @inherited_from end |
#permission_type ⇒ String
Output only. The permission type for this user. While new values may be added
in future, the following are currently possible: * file * member
Corresponds to the JSON property permissionType
3946 3947 3948 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3946 def @permission_type end |
#role ⇒ String
Output only. The primary role for this user. While new values may be added in
the future, the following are currently possible: * organizer *
fileOrganizer * writer * reader
Corresponds to the JSON property role
3953 3954 3955 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3953 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3960 3961 3962 3963 3964 3965 3966 |
# File 'lib/google/apis/drive_v2/classes.rb', line 3960 def update!(**args) @additional_roles = args[:additional_roles] if args.key?(:additional_roles) @inherited = args[:inherited] if args.key?(:inherited) @inherited_from = args[:inherited_from] if args.key?(:inherited_from) @permission_type = args[:permission_type] if args.key?(:permission_type) @role = args[:role] if args.key?(:role) end |