Class: Google::Apis::DriveV2::Property
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::Property
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
A key-value pair attached to a file that is either public or private to an
application. The following limits apply to file properties: * Maximum of 100
properties total per file * Maximum of 30 private properties per app * Maximum
of 30 public properties * Maximum of 124 bytes size limit on (key + value)
string in UTF-8 encoding for a single property Some resource methods (such as
properties.update) require a propertyKey. Use the properties.list method
to retrieve the key for a property.
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#key ⇒ String
The key of this property.
-
#kind ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#value ⇒ String
The value of this property.
-
#visibility ⇒ String
The visibility of this property.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Property
constructor
A new instance of Property.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Property
Returns a new instance of Property.
4128 4129 4130 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. ETag of the property.
Corresponds to the JSON property etag
4098 4099 4100 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4098 def etag @etag end |
#key ⇒ String
The key of this property.
Corresponds to the JSON property key
4103 4104 4105 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4103 def key @key end |
#kind ⇒ String
Output only. This is always drive#property.
Corresponds to the JSON property kind
4108 4109 4110 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4108 def kind @kind end |
#self_link ⇒ String
Output only. The link back to this property.
Corresponds to the JSON property selfLink
4113 4114 4115 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4113 def self_link @self_link end |
#value ⇒ String
The value of this property.
Corresponds to the JSON property value
4118 4119 4120 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4118 def value @value end |
#visibility ⇒ String
The visibility of this property. Allowed values are PRIVATE (default) and
PUBLIC. Private properties can only be retrieved using an authenticated
request. An authenticated request uses an access token obtained with a OAuth 2
client ID. You cannot use an API key to retrieve private properties.
Corresponds to the JSON property visibility
4126 4127 4128 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4126 def visibility @visibility end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4133 4134 4135 4136 4137 4138 4139 4140 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4133 def update!(**args) @etag = args[:etag] if args.key?(:etag) @key = args[:key] if args.key?(:key) @kind = args[:kind] if args.key?(:kind) @self_link = args[:self_link] if args.key?(:self_link) @value = args[:value] if args.key?(:value) @visibility = args[:visibility] if args.key?(:visibility) end |