Class: Google::Apis::DriveV2::User
- Inherits:
-
Object
- Object
- Google::Apis::DriveV2::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v2/classes.rb,
lib/google/apis/drive_v2/representations.rb,
lib/google/apis/drive_v2/representations.rb
Overview
Information about a Drive user.
Defined Under Namespace
Classes: Picture
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#email_address ⇒ String
Output only.
-
#is_authenticated_user ⇒ Boolean
(also: #is_authenticated_user?)
Output only.
-
#kind ⇒ String
Output only.
-
#permission_id ⇒ String
Output only.
-
#picture ⇒ Google::Apis::DriveV2::User::Picture
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
4831 4832 4833 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. A plain text displayable name for this user.
Corresponds to the JSON property displayName
4800 4801 4802 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4800 def display_name @display_name end |
#email_address ⇒ String
Output only. The email address of the user. This may not be present in certain
contexts if the user has not made their email address visible to the requester.
Corresponds to the JSON property emailAddress
4806 4807 4808 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4806 def email_address @email_address end |
#is_authenticated_user ⇒ Boolean Also known as: is_authenticated_user?
Output only. Whether this user is the same as the authenticated user for whom
the request was made.
Corresponds to the JSON property isAuthenticatedUser
4812 4813 4814 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4812 def is_authenticated_user @is_authenticated_user end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
drive#user.
Corresponds to the JSON property kind
4819 4820 4821 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4819 def kind @kind end |
#permission_id ⇒ String
Output only. The user's ID as visible in Permission resources.
Corresponds to the JSON property permissionId
4824 4825 4826 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4824 def @permission_id end |
#picture ⇒ Google::Apis::DriveV2::User::Picture
Output only. The user's profile picture.
Corresponds to the JSON property picture
4829 4830 4831 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4829 def picture @picture end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4836 4837 4838 4839 4840 4841 4842 4843 |
# File 'lib/google/apis/drive_v2/classes.rb', line 4836 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @email_address = args[:email_address] if args.key?(:email_address) @is_authenticated_user = args[:is_authenticated_user] if args.key?(:is_authenticated_user) @kind = args[:kind] if args.key?(:kind) @permission_id = args[:permission_id] if args.key?(:permission_id) @picture = args[:picture] if args.key?(:picture) end |